@@ -34,6 +34,7 @@ class Australia(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, S
           * <https://web.archive.org/web/20250414072303/https://www.qld.gov.au/recreation/travel/holidays>
           * [ACT Holidays Act 1958](https://web.archive.org/web/20250322061953/https://www.legislation.act.gov.au/a/1958-19/)
           * [ACT 2013-2023](https://web.archive.org/web/20240401072340/https://www.cmtedd.act.gov.au/archived-content/holidays/previous-years)
+          * [ACT Holidays (Anzac Day 2026) Declaration 2025 (No 1)](https://web.archive.org/web/20260116225801/https://legislation.act.gov.au/View/ni/2025-650/current/html/2025-650.html)
           * [NSW Banks and Bank Holidays Act 1912](https://web.archive.org/web/20241107225523/https://legislation.nsw.gov.au/view/html/repealed/current/act-1912-043)
           * [NSW Public Holidays Act 2010](https://web.archive.org/web/20250316173922/https://legislation.nsw.gov.au/view/html/inforce/current/act-2010-115)
           * [NT Public Holidays Act 1981](https://web.archive.org/web/20250315072128/https://legislation.nt.gov.au/api/sitecore/Act/PDF?id=12145)
@@ -189,11 +190,14 @@ class Australia(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, S
 
         # ANZAC Day.
         # from 1959: SUN - move to MON.
+        # in 2026: move to MON.
 
         if self._year >= 1921:
             # ANZAC Day.
             dt = self._add_anzac_day(tr("ANZAC Day"))
-            if self._year >= 1959:
+            if self._year == 2026:
+                self._move_holiday(dt, rule=SAT_SUN_TO_NEXT_MON, show_observed_label=False)
+            elif self._year >= 1959:
                 self._move_holiday(dt, rule=SUN_TO_NEXT_MON, show_observed_label=False)
 
         # Easter Saturday.
@@ -532,6 +536,14 @@ class Australia(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, S
         elif self._year >= 1984:
             self._move_holiday(dt, rule=SUN_TO_NEXT_MON, show_observed_label=False)
 
+    def _populate_subdiv_qld_half_day_holidays(self):
+        if self._year >= 2019:
+            # %s (from 6pm).
+            begin_time_label = self.tr("%s (from 6pm)")
+
+            # Christmas Eve.
+            self._add_christmas_eve(begin_time_label % self.tr("Christmas Eve"))
+
     def _populate_subdiv_sa_public_holidays(self):
         # New Year's Day.
         # 1984-2003: SAT, SUN - move to MON.
@@ -566,7 +578,7 @@ class Australia(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, S
                 self._move_holiday(dt, rule=ALL_TO_NEXT_MON, show_observed_label=False)
 
         # Adelaide Cup Day.
-        # First observed as Public Holidays in 1973: https://racingsa.com.au/blog/2020/03/06/2380/a-little-adelaide-cup-history
+        # First observed as Public Holidays in 1973: https://web.archive.org/web/20260122052707/https://www.racingsa.com.au/news/a-little-adelaide-cup-history
         # 2006-2023: changed each year by SA Government Proclamation from the 3rd Monday in May
         # to the 2nd Monday in March.
         # from 2024: changed to the 2nd Monday in March officially.
