@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -27,7 +27,7 @@ class Greece(ObservedHolidayBase, ChristianHolidays, InternationalHolidays):
 
     References:
         * <https://en.wikipedia.org/wiki/Public_holidays_in_Greece>
-        * [2024 Labor Day transfer](https://www.et.gr/api/DownloadFeksApi/?fek_pdf=20240201406)
+        * [2024 Labor Day transfer](https://web.archive.org/web/20240813221449/https://www.et.gr/api/DownloadFeksApi/?fek_pdf=20240201406)
     """
 
     country = "GR"
