@@ -37,6 +37,8 @@ class India(
         * <https://web.archive.org/web/20250413193633/https://www.calendarlabs.com/holidays/india/2021>
         * <https://web.archive.org/web/20231118175007/http://slusi.dacnet.nic.in/watershedatlas/list_of_state_abbreviation.htm>
         * <https://web.archive.org/web/20231008063930/https://vahan.parivahan.gov.in/vahan4dashboard/>
+        * Gujarat:
+            * <https://web.archive.org/web/20260122052040/https://images-gujarati.indianexpress.com/2025/11/gujarat-government-Year-2026-holiday-list.pdf>
         * Tamil Nadu:
             * [Tamil Monthly Calendar](https://web.archive.org/web/20231228103352/https://www.tamildailycalendar.com/tamil_monthly_calendar.php)
             * [Tamil Calendar](https://web.archive.org/web/20250429125140/https://www.prokerala.com/general/calendar/tamilcalendar.php)
@@ -144,7 +146,7 @@ class India(
         "West Bengal": "WB",
     }
     supported_categories = (OPTIONAL, PUBLIC)
-    supported_languages = ("en_IN", "en_US", "hi")
+    supported_languages = ("en_IN", "en_US", "gu", "hi")
     _deprecated_subdivisions = (
         "DD",  # Daman and Diu.
         "OR",  # Orissa.
@@ -456,7 +458,7 @@ class India(
         # Dr. B. R. Ambedkar Jayanti.
         self._add_holiday_apr_14(tr("Dr. B. R. Ambedkar's Jayanti"))
         # Maharana Pratap Jayanti.
-        self._add_holiday_jun_15(tr("Maharana Pratap Jayanti"))
+        self._add_maharana_pratap_jayanti(tr("Maharana Pratap Jayanti"))
 
     # Sikkim.
     def _populate_subdiv_sk_public_holidays(self):
@@ -485,7 +487,7 @@ class India(
         # Telangana Formation Day.
         self._add_holiday_jun_2(tr("Telangana Formation Day"))
         # Bathukamma Festival.
-        self._add_holiday_oct_6(tr("Bathukamma Festival"))
+        self._add_bathukamma(tr("Bathukamma Festival"))
         # Ugadi.
         self._add_gudi_padwa(tr("Ugadi"))
 
