@@ -10,6 +10,7 @@
 #  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
+from holidays.constants import HALF_DAY, PUBLIC, UNOFFICIAL
 from holidays.countries.united_states import UnitedStates
 from holidays.mixins.child_entity import ChildEntity
 
@@ -23,8 +24,9 @@ class PuertoRico(ChildEntity, UnitedStates):
 
     country = "PR"
     parent_entity = UnitedStates
-    # Became a U.S. Territory on April 11th, 1899.
-    start_year = 1900
+    # Art. 387 of the 1902 Political Code of Puerto Rico.
+    start_year = 1903
+    supported_categories = (HALF_DAY, PUBLIC, UNOFFICIAL)
 
 
 class HolidaysPR(PuertoRico):
