@@ -10,6 +10,7 @@
 #  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
+from holidays.constants import PUBLIC, UNOFFICIAL
 from holidays.countries.united_states import UnitedStates
 from holidays.mixins.child_entity import ChildEntity
 
@@ -25,6 +26,7 @@ class UnitedStatesVirginIslands(ChildEntity, UnitedStates):
     parent_entity = UnitedStates
     # Became a U.S. Territory since March 31st, 1917.
     start_year = 1918
+    supported_categories = (PUBLIC, UNOFFICIAL)
 
 
 class HolidaysVI(UnitedStatesVirginIslands):
