@@ -11,7 +11,6 @@
 #  License: MIT (see LICENSE file)
 
 from datetime import date
-from typing import Optional
 
 from holidays.calendars.tibetan import _TibetanLunisolar
 from holidays.groups.eastern import EasternCalendarHolidays
@@ -27,8 +26,8 @@ class TibetanCalendarHolidays(EasternCalendarHolidays):
         self._tibetan_calendar_show_estimated = show_estimated
 
     def _add_tibetan_calendar_holiday(
-        self, name: str, dt_estimated: tuple[Optional[date], bool], days_delta: int = 0
-    ) -> Optional[date]:
+        self, name: str, dt_estimated: tuple[date | None, bool], days_delta: int = 0
+    ) -> date | None:
         """
         Add Tibetan calendar holiday.
 
@@ -42,7 +41,7 @@ class TibetanCalendarHolidays(EasternCalendarHolidays):
             days_delta=days_delta,
         )
 
-    def _add_blessed_rainy_day(self, name) -> Optional[date]:
+    def _add_blessed_rainy_day(self, name) -> date | None:
         """
         Add Blessed Rainy Day (September Equinox of Autumn Calendar).
         """
@@ -50,7 +49,7 @@ class TibetanCalendarHolidays(EasternCalendarHolidays):
             name, self._tibetan_calendar.blessed_rainy_day_date(self._year)
         )
 
-    def _add_birth_of_guru_rinpoche(self, name) -> Optional[date]:
+    def _add_birth_of_guru_rinpoche(self, name) -> date | None:
         """
         Add Birth of Guru Rinpoche (10th day of the 5th lunar month).
         """
@@ -58,7 +57,7 @@ class TibetanCalendarHolidays(EasternCalendarHolidays):
             name, self._tibetan_calendar.birth_of_guru_rinpoche_date(self._year)
         )
 
-    def _add_buddha_first_sermon(self, name) -> Optional[date]:
+    def _add_buddha_first_sermon(self, name) -> date | None:
         """
         Add Buddha First Sermon (4th day of the 6th lunar month).
         """
@@ -66,7 +65,7 @@ class TibetanCalendarHolidays(EasternCalendarHolidays):
             name, self._tibetan_calendar.buddha_first_sermon_date(self._year)
         )
 
-    def _add_buddha_parinirvana(self, name) -> Optional[date]:
+    def _add_buddha_parinirvana(self, name) -> date | None:
         """
         Add Buddha Parinirvana (15th day of the 4th lunar month).
         """
@@ -74,7 +73,7 @@ class TibetanCalendarHolidays(EasternCalendarHolidays):
             name, self._tibetan_calendar.buddha_parinirvana_date(self._year)
         )
 
-    def _add_day_of_offering(self, name) -> Optional[date]:
+    def _add_day_of_offering(self, name) -> date | None:
         """
         Add Day of Offering (1st day of the 12th lunar month).
         """
@@ -82,7 +81,7 @@ class TibetanCalendarHolidays(EasternCalendarHolidays):
             name, self._tibetan_calendar.day_of_offering_date(self._year)
         )
 
-    def _add_death_of_zhabdrung(self, name) -> Optional[date]:
+    def _add_death_of_zhabdrung(self, name) -> date | None:
         """
         Add Death of Zhabdrung (10th day of the 3rd lunar month).
         """
@@ -90,7 +89,7 @@ class TibetanCalendarHolidays(EasternCalendarHolidays):
             name, self._tibetan_calendar.death_of_zhabdrung_date(self._year)
         )
 
-    def _add_descending_day_of_lord_buddha(self, name) -> Optional[date]:
+    def _add_descending_day_of_lord_buddha(self, name) -> date | None:
         """
         Add Descending Day of Lord Buddha (22nd day of the 9th lunar month).
         """
@@ -98,7 +97,7 @@ class TibetanCalendarHolidays(EasternCalendarHolidays):
             name, self._tibetan_calendar.descending_day_of_lord_buddha_date(self._year)
         )
 
-    def _add_losar(self, name) -> Optional[date]:
+    def _add_losar(self, name) -> date | None:
         """
         Add Losar (1st day of the 1st lunar month).
         """
@@ -106,7 +105,7 @@ class TibetanCalendarHolidays(EasternCalendarHolidays):
             name, self._tibetan_calendar.losar_date(self._year)
         )
 
-    def _add_losar_day_two(self, name) -> Optional[date]:
+    def _add_losar_day_two(self, name) -> date | None:
         """
         Add Losar Day Two.
         """
@@ -114,7 +113,7 @@ class TibetanCalendarHolidays(EasternCalendarHolidays):
             name, self._tibetan_calendar.losar_date(self._year), days_delta=+1
         )
 
-    def _add_thimphu_drubchen_day(self, name) -> Optional[date]:
+    def _add_thimphu_drubchen_day(self, name) -> date | None:
         """
         Add Thimphu Drubchen (6th day of the 8th lunar month).
         """
@@ -122,7 +121,7 @@ class TibetanCalendarHolidays(EasternCalendarHolidays):
             name, self._tibetan_calendar.thimphu_drubchen_date(self._year), days_delta=+1
         )
 
-    def _add_thimphu_tshechu_day(self, name) -> Optional[date]:
+    def _add_thimphu_tshechu_day(self, name) -> date | None:
         """
         Add Thimphu Tshechu (10th day of the 8th lunar month).
         """
@@ -130,7 +129,7 @@ class TibetanCalendarHolidays(EasternCalendarHolidays):
             name, self._tibetan_calendar.thimphu_tshechu_date(self._year)
         )
 
-    def _add_thimphu_tshechu_day_two(self, name) -> Optional[date]:
+    def _add_thimphu_tshechu_day_two(self, name) -> date | None:
         """
         Add Thimphu Tshechu Day 2.
         """
@@ -138,7 +137,7 @@ class TibetanCalendarHolidays(EasternCalendarHolidays):
             name, self._tibetan_calendar.thimphu_tshechu_date(self._year), days_delta=+1
         )
 
-    def _add_thimphu_tshechu_day_three(self, name) -> Optional[date]:
+    def _add_thimphu_tshechu_day_three(self, name) -> date | None:
         """
         Add Thimphu Tshechu Day 3.
         """
@@ -146,7 +145,7 @@ class TibetanCalendarHolidays(EasternCalendarHolidays):
             name, self._tibetan_calendar.thimphu_tshechu_date(self._year), days_delta=+2
         )
 
-    def _add_tibetan_winter_solstice(self, name) -> Optional[date]:
+    def _add_tibetan_winter_solstice(self, name) -> date | None:
         """
         Add Winter Solstice Day.
         """
