@@ -12,6 +12,7 @@
 
 from unittest import TestCase
 
+from holidays.constants import WORKDAY
 from holidays.countries.azerbaijan import Azerbaijan
 from tests.common import CommonCountryTests, WorkingDayTests
 
@@ -22,6 +23,11 @@ class TestAzerbaijan(CommonCountryTests, WorkingDayTests, TestCase):
         cls.full_range = range(1990, 2073)
         super().setUpClass(Azerbaijan)
 
+    def test_no_holidays(self):
+        super().test_no_holidays()
+
+        self.assertNoHolidays(Azerbaijan(categories=WORKDAY, years=range(self.start_year, 1992)))
+
     def test_special_holidays(self):
         self.assertHoliday(
             "2007-01-03",
