@@ -55,19 +55,15 @@ class TestCambodia(CommonCountryTests, TestCase):
             ("2022-09-26", "ពិធីបុណ្យភ្ផុំបិណ្ឌ"),
             (
                 "2022-10-15",
-                (
-                    "ទិវាប្រារព្ឋពិធីគោរពព្រះវិញ្ញាណក្ខន្ឋ ព្រះករុណា ព្រះបាទសម្តេចព្រះ នរោត្តម "
-                    "សីហនុ ព្រះមហាវីរក្សត្រ ព្រះវររាជបិតាឯករាជ្យ បូរណភាពទឹកដី "
-                    "និងឯកភាពជាតិខ្មែរ ព្រះបរមរតនកោដ្ឋ"
-                ),
+                "ទិវាប្រារព្ឋពិធីគោរពព្រះវិញ្ញាណក្ខន្ឋ ព្រះករុណា ព្រះបាទសម្តេចព្រះ នរោត្តម "
+                "សីហនុ ព្រះមហាវីរក្សត្រ ព្រះវររាជបិតាឯករាជ្យ បូរណភាពទឹកដី "
+                "និងឯកភាពជាតិខ្មែរ ព្រះបរមរតនកោដ្ឋ",
             ),
             (
                 "2022-10-29",
-                (
-                    "ព្រះរាជពិធីគ្រងព្រះបរមរាជសម្បត្តិ របស់ ព្រះករុណា "
-                    "ព្រះបាទសម្តេចព្រះបរមនាថ នរោត្តម សីហមុនី "
-                    "ព្រះមហាក្សត្រនៃព្រះរាជាណាចក្រកម្ពុជា"
-                ),
+                "ព្រះរាជពិធីគ្រងព្រះបរមរាជសម្បត្តិ របស់ ព្រះករុណា "
+                "ព្រះបាទសម្តេចព្រះបរមនាថ នរោត្តម សីហមុនី "
+                "ព្រះមហាក្សត្រនៃព្រះរាជាណាចក្រកម្ពុជា",
             ),
             ("2022-11-07", "ព្រះរាជពិធីបុណ្យអុំទូក បណ្តែតប្រទីប និងសំពះព្រះខែអកអំបុក"),
             ("2022-11-08", "ព្រះរាជពិធីបុណ្យអុំទូក បណ្តែតប្រទីប និងសំពះព្រះខែអកអំបុក"),
@@ -93,19 +89,15 @@ class TestCambodia(CommonCountryTests, TestCase):
             ("2023-10-14", "ពិធីបុណ្យភ្ផុំបិណ្ឌ"),
             (
                 "2023-10-15",
-                (
-                    "ទិវាប្រារព្ឋពិធីគោរពព្រះវិញ្ញាណក្ខន្ឋ ព្រះករុណា ព្រះបាទសម្តេចព្រះ នរោត្តម "
-                    "សីហនុ ព្រះមហាវីរក្សត្រ ព្រះវររាជបិតាឯករាជ្យ បូរណភាពទឹកដី "
-                    "និងឯកភាពជាតិខ្មែរ ព្រះបរមរតនកោដ្ឋ; ពិធីបុណ្យភ្ផុំបិណ្ឌ"
-                ),
+                "ទិវាប្រារព្ឋពិធីគោរពព្រះវិញ្ញាណក្ខន្ឋ ព្រះករុណា ព្រះបាទសម្តេចព្រះ នរោត្តម "
+                "សីហនុ ព្រះមហាវីរក្សត្រ ព្រះវររាជបិតាឯករាជ្យ បូរណភាពទឹកដី "
+                "និងឯកភាពជាតិខ្មែរ ព្រះបរមរតនកោដ្ឋ; ពិធីបុណ្យភ្ផុំបិណ្ឌ",
             ),
             (
                 "2023-10-29",
-                (
-                    "ព្រះរាជពិធីគ្រងព្រះបរមរាជសម្បត្តិ របស់ ព្រះករុណា "
-                    "ព្រះបាទសម្តេចព្រះបរមនាថ នរោត្តម សីហមុនី "
-                    "ព្រះមហាក្សត្រនៃព្រះរាជាណាចក្រកម្ពុជា"
-                ),
+                "ព្រះរាជពិធីគ្រងព្រះបរមរាជសម្បត្តិ របស់ ព្រះករុណា "
+                "ព្រះបាទសម្តេចព្រះបរមនាថ នរោត្តម សីហមុនី "
+                "ព្រះមហាក្សត្រនៃព្រះរាជាណាចក្រកម្ពុជា",
             ),
             ("2023-11-09", "ពិធីបុណ្យឯករាជ្យជាតិ"),
             ("2023-11-26", "ព្រះរាជពិធីបុណ្យអុំទូក បណ្តែតប្រទីប និងសំពះព្រះខែអកអំបុក"),
@@ -359,19 +351,15 @@ class TestCambodia(CommonCountryTests, TestCase):
             ("2023-10-14", "ពិធីបុណ្យភ្ផុំបិណ្ឌ"),
             (
                 "2023-10-15",
-                (
-                    "ទិវាប្រារព្ឋពិធីគោរពព្រះវិញ្ញាណក្ខន្ឋ ព្រះករុណា ព្រះបាទសម្តេចព្រះ នរោត្តម "
-                    "សីហនុ ព្រះមហាវីរក្សត្រ ព្រះវររាជបិតាឯករាជ្យ បូរណភាពទឹកដី "
-                    "និងឯកភាពជាតិខ្មែរ ព្រះបរមរតនកោដ្ឋ; ពិធីបុណ្យភ្ផុំបិណ្ឌ"
-                ),
+                "ទិវាប្រារព្ឋពិធីគោរពព្រះវិញ្ញាណក្ខន្ឋ ព្រះករុណា ព្រះបាទសម្តេចព្រះ នរោត្តម "
+                "សីហនុ ព្រះមហាវីរក្សត្រ ព្រះវររាជបិតាឯករាជ្យ បូរណភាពទឹកដី "
+                "និងឯកភាពជាតិខ្មែរ ព្រះបរមរតនកោដ្ឋ; ពិធីបុណ្យភ្ផុំបិណ្ឌ",
             ),
             (
                 "2023-10-29",
-                (
-                    "ព្រះរាជពិធីគ្រងព្រះបរមរាជសម្បត្តិ របស់ ព្រះករុណា "
-                    "ព្រះបាទសម្តេចព្រះបរមនាថ នរោត្តម សីហមុនី "
-                    "ព្រះមហាក្សត្រនៃព្រះរាជាណាចក្រកម្ពុជា"
-                ),
+                "ព្រះរាជពិធីគ្រងព្រះបរមរាជសម្បត្តិ របស់ ព្រះករុណា "
+                "ព្រះបាទសម្តេចព្រះបរមនាថ នរោត្តម សីហមុនី "
+                "ព្រះមហាក្សត្រនៃព្រះរាជាណាចក្រកម្ពុជា",
             ),
             ("2023-11-09", "ពិធីបុណ្យឯករាជ្យជាតិ"),
             ("2023-11-26", "ព្រះរាជពិធីបុណ្យអុំទូក បណ្តែតប្រទីប និងសំពះព្រះខែអកអំបុក"),
@@ -418,10 +406,8 @@ class TestCambodia(CommonCountryTests, TestCase):
             ("2023-05-08", "พระราชพิธีบุญจรดพระนังคัลแรกนาขวัญ"),
             (
                 "2023-05-14",
-                (
-                    "พระราชพิธีเฉลิมพระชนมพรรษา พระบาทสมเด็จพระบรมนาถ นโรดมสีหมุนี "
-                    "พระมหากษัตริย์แห่งราชอาณาจักรกัมพูชา"
-                ),
+                "พระราชพิธีเฉลิมพระชนมพรรษา พระบาทสมเด็จพระบรมนาถ นโรดมสีหมุนี "
+                "พระมหากษัตริย์แห่งราชอาณาจักรกัมพูชา",
             ),
             ("2023-06-18", "พระราชพิธีเฉลิมพระชนมพรรษา สมเด็จพระบรมราชินี นโรดม มนีนาถ สีหนุ"),
             ("2023-09-24", "วันรัฐธรรมนูญ"),
@@ -429,17 +415,13 @@ class TestCambodia(CommonCountryTests, TestCase):
             ("2023-10-14", "เทศกาลงานวันสาร์ทภจุมบิณฑ์เขมร"),
             (
                 "2023-10-15",
-                (
-                    "วันสดุดีพระบาทสมเด็จพระบรมนาถนโรดม สีหนุ พระบิดาแห่งเอกราช "
-                    "บูรณภาพแห่งดินแดน และเอกภาพของชาติกัมพูชา; เทศกาลงานวันสาร์ทภจุมบิณฑ์เขมร"
-                ),
+                "วันสดุดีพระบาทสมเด็จพระบรมนาถนโรดม สีหนุ พระบิดาแห่งเอกราช "
+                "บูรณภาพแห่งดินแดน และเอกภาพของชาติกัมพูชา; เทศกาลงานวันสาร์ทภจุมบิณฑ์เขมร",
             ),
             (
                 "2023-10-29",
-                (
-                    "พระราชพิธีเฉลิมฉลองการขึ้นครองราชสมบัติ พระบาทสมเด็จพระบรมนาถ นโรดมสีหมุนี "
-                    "พระมหากษัตริย์แห่งราชอาณาจักรกัมพูชา"
-                ),
+                "พระราชพิธีเฉลิมฉลองการขึ้นครองราชสมบัติ พระบาทสมเด็จพระบรมนาถ นโรดมสีหมุนี "
+                "พระมหากษัตริย์แห่งราชอาณาจักรกัมพูชา",
             ),
             ("2023-11-09", "วันประกาศเอกราชจากฝรั่งเศส"),
             ("2023-11-26", "พระราชพิธีบุญแข่งเรือลอยกระทงไฟไหว้พระจันทร์และกินข้าวเม่า"),
