@@ -24,7 +24,8 @@ class TestEstonia(CommonCountryTests, TestCase):
 
     def test_no_holidays(self):
         super().test_no_holidays()
-        self.assertNoHolidays(Estonia(categories=HALF_DAY, years=2000))
+
+        self.assertNoHolidays(Estonia(categories=HALF_DAY, years=range(self.start_year, 2001)))
 
     def test_new_years_day(self):
         self.assertHolidayName("uusaasta", (f"{year}-01-01" for year in self.full_range))
