@@ -137,7 +137,7 @@ class TestIndia(CommonCountryTests, TestCase):
             "RJ": (
                 "2018-03-30",
                 "2018-04-14",
-                "2018-06-15",
+                "2018-06-16",
             ),
             "SK": (
                 "2018-04-14",
@@ -152,7 +152,7 @@ class TestIndia(CommonCountryTests, TestCase):
             "TS": (
                 "2018-04-14",
                 "2018-06-02",
-                "2018-10-06",
+                "2018-10-08",
             ),
             "UK": ("2018-04-14",),
             "UP": (
@@ -551,8 +551,7 @@ class TestIndia(CommonCountryTests, TestCase):
             ("2018-05-09", "Rabindra Jayanti"),
             ("2018-05-16", "Sikkim State Day"),
             ("2018-06-02", "Telangana Formation Day"),
-            ("2018-06-15", "Maharana Pratap Jayanti"),
-            ("2018-06-16", "Id-ul-Fitr"),
+            ("2018-06-16", "Id-ul-Fitr; Maharana Pratap Jayanti"),
             ("2018-08-15", "Independence Day"),
             ("2018-08-16", "Puducherry De Jure Transfer Day"),
             ("2018-08-22", "Bakrid"),
@@ -562,7 +561,7 @@ class TestIndia(CommonCountryTests, TestCase):
             ("2018-09-13", "Ganesh Chaturthi"),
             ("2018-09-21", "Muharram"),
             ("2018-10-02", "Gandhi Jayanti"),
-            ("2018-10-06", "Bathukamma Festival"),
+            ("2018-10-08", "Bathukamma Festival"),
             ("2018-10-10", "Navratri / Sharad Navratri"),
             ("2018-10-17", "Maha Navami"),
             ("2018-10-19", "Dussehra"),
@@ -590,6 +589,68 @@ class TestIndia(CommonCountryTests, TestCase):
             ("2018-12-25", "Christmas"),
         )
 
+    def test_l10n_gu(self):
+        self.assertLocalizedHolidays(
+            "gu",
+            ("2018-01-13", "લોહરી"),
+            ("2018-01-14", "ઉત્તરાયણ; પોંગલ; મકરસંક્રાંતિ; માઘ બિહુ"),
+            ("2018-01-15", "તિરુવલ્લુવર દિવસ / મટ્ટુ પોંગલ"),
+            ("2018-01-16", "ઉઝાવર થિરુનલ"),
+            ("2018-01-24", "યુપી સ્થાપના દિવસ"),
+            ("2018-01-26", "પ્રજાસત્તાક દિવસ"),
+            ("2018-02-13", "મહાશિવરાત્રી"),
+            ("2018-02-19", "છત્રપતિ શિવાજી મહારાજ જયંતિ"),
+            ("2018-02-20", "મિઝોરમ રાજ્ય દિવસ"),
+            ("2018-03-02", "હોળી"),
+            ("2018-03-18", "ઉગાડી; ગુડી પડવો"),
+            ("2018-03-22", "બિહાર દિવસ"),
+            ("2018-03-25", "પામ સન્ડે; રામ નવમી"),
+            ("2018-03-29", "મહાવીર જયંતિ"),
+            ("2018-03-30", "ગુડ ફ્રાઈડે; રાજસ્થાન દિવસ"),
+            ("2018-04-01", "ઈસ્ટર સન્ડે; ઓડિશા દિવસ (ઉત્કલ દિવસ)"),
+            ("2018-04-14", "ડૉ. બી. આર. આંબેડકર જયંતિ; પુથંડુ (તમિલ નવું વર્ષ); વૈશાખી"),
+            ("2018-04-15", "પોહેલા બોઈશાખ; મહા વિષુવ સંક્રાંતિ / પાના સંક્રાંતિ; હિમાચલ દિવસ"),
+            ("2018-04-30", "બુદ્ધ પૂર્ણિમા"),
+            ("2018-05-01", "ગુજરાત સ્થાપના દિવસ; મજૂર દિવસ; મહારાષ્ટ્ર દિવસ"),
+            ("2018-05-09", "રવીન્દ્ર જયંતિ"),
+            ("2018-05-16", "સિક્કિમ રાજ્ય દિવસ"),
+            ("2018-06-02", "તેલંગાણા સ્થાપના દિવસ"),
+            ("2018-06-16", "ઈદ-ઉલ-ફિત્ર; મહારાણા પ્રતાપ જયંતિ"),
+            ("2018-08-15", "સ્વતંત્રતા દિવસ"),
+            ("2018-08-16", "પુડુચેરી ડી જ્યુર ટ્રાન્સફર દિવસ"),
+            ("2018-08-22", "બકરી ઈદ"),
+            ("2018-08-24", "ઓણમ"),
+            ("2018-08-26", "રક્ષાબંધન"),
+            ("2018-09-03", "જન્માષ્ટમી"),
+            ("2018-09-13", "ગણેશ ચતુર્થી"),
+            ("2018-09-21", "મોહરમ"),
+            ("2018-10-02", "ગાંધી જયંતિ"),
+            ("2018-10-08", "બથુકમ્મા ઉત્સવ"),
+            ("2018-10-10", "નવરાત્રી / શરદ નવરાત્રી"),
+            ("2018-10-17", "મહાનવમી"),
+            ("2018-10-19", "દશેરા"),
+            ("2018-10-31", "સરદાર વલ્લભભાઈ પટેલ જયંતિ"),
+            (
+                "2018-11-01",
+                "આંધ્ર પ્રદેશ સ્થાપના દિવસ; "
+                "કર્ણાટક રાજ્યોત્સવ; કેરળ સ્થાપના દિવસ; "
+                "છત્તીસગઢ સ્થાપના દિવસ; પંજાબ દિવસ; "
+                "પુડુચેરી મુક્તિ દિવસ; મધ્ય પ્રદેશ સ્થાપના દિવસ; "
+                "હરિયાણા સ્થાપના દિવસ",
+            ),
+            ("2018-11-07", "દિવાળી"),
+            ("2018-11-08", "ગોવર્ધન પૂજા"),
+            ("2018-11-13", "છઠ પૂજા"),
+            ("2018-11-14", "બાળ દિવસ"),
+            ("2018-11-15", "ઝારખંડ સ્થાપના દિવસ"),
+            ("2018-11-21", "મિલાદ-ઉન-નબી"),
+            ("2018-11-23", "ગુરુ નાનક જયંતિ"),
+            ("2018-12-01", "નાગાલેન્ડ રાજ્ય ઉદ્ઘાટન દિવસ"),
+            ("2018-12-02", "આસામ દિવસ"),
+            ("2018-12-19", "ગોવા મુક્તિ દિવસ"),
+            ("2018-12-25", "નાતાલ"),
+        )
+
     def test_l10n_hi(self):
         self.assertLocalizedHolidays(
             "hi",
@@ -616,8 +677,7 @@ class TestIndia(CommonCountryTests, TestCase):
             ("2018-05-09", "रवींद्र जयंती"),
             ("2018-05-16", "सिक्किम राज्य दिवस"),
             ("2018-06-02", "तेलंगाना स्थापना दिवस"),
-            ("2018-06-15", "महाराणा प्रताप जयंती"),
-            ("2018-06-16", "ईद-उल-फितर"),
+            ("2018-06-16", "ईद-उल-फितर; महाराणा प्रताप जयंती"),
             ("2018-08-15", "स्वतंत्रता दिवस"),
             ("2018-08-16", "पुडुचेरी डी ज्यूर स्थानांतरण दिवस"),
             ("2018-08-22", "बकरीद"),
@@ -627,7 +687,7 @@ class TestIndia(CommonCountryTests, TestCase):
             ("2018-09-13", "गणेश चतुर्थी"),
             ("2018-09-21", "मुहर्रम"),
             ("2018-10-02", "गांधी जयंती"),
-            ("2018-10-06", "बतुकम्मा महोत्सव"),
+            ("2018-10-08", "बतुकम्मा महोत्सव"),
             ("2018-10-10", "नवरात्र/शरद नवरात्र"),
             ("2018-10-17", "महानवमी"),
             ("2018-10-19", "दशहरा"),
@@ -682,8 +742,7 @@ class TestIndia(CommonCountryTests, TestCase):
             ("2018-05-09", "Rabindra Jayanti"),
             ("2018-05-16", "Sikkim State Day"),
             ("2018-06-02", "Telangana Formation Day"),
-            ("2018-06-15", "Maharana Pratap Jayanti"),
-            ("2018-06-16", "Eid al-Fitr"),
+            ("2018-06-16", "Eid al-Fitr; Maharana Pratap Jayanti"),
             ("2018-08-15", "Independence Day"),
             ("2018-08-16", "Puducherry De Jure Transfer Day"),
             ("2018-08-22", "Eid al-Adha"),
@@ -693,7 +752,7 @@ class TestIndia(CommonCountryTests, TestCase):
             ("2018-09-13", "Ganesh Chaturthi"),
             ("2018-09-21", "Ashura"),
             ("2018-10-02", "Gandhi Jayanti"),
-            ("2018-10-06", "Bathukamma Festival"),
+            ("2018-10-08", "Bathukamma Festival"),
             ("2018-10-10", "Navratri / Sharad Navratri"),
             ("2018-10-17", "Maha Navami"),
             ("2018-10-19", "Dussehra"),
