@@ -20,63 +20,65 @@ from tests.common import CommonCountryTests
 class TestLibya(CommonCountryTests, TestCase):
     @classmethod
     def setUpClass(cls):
-        years = range(1988, 2050)
-        super().setUpClass(Libya, years=years)
-        cls.workday_holidays = Libya(years=years, categories=WORKDAY, islamic_show_estimated=False)
-        cls.no_estimated_holidays = Libya(years=years, islamic_show_estimated=False)
+        super().setUpClass(Libya)
+
+    def test_no_holidays(self):
+        super().test_no_holidays()
+
+        self.assertNoHolidays(Libya(categories=WORKDAY, years=range(2012, self.end_year)))
 
     def test_special_holidays(self):
         self.assertHolidayName("عطلة رسمية", "2023-12-10")
 
     def test_peoples_authority_day(self):
         name = "عید إعلان سلطة الشعب"
-        self.assertHolidayName(name, (f"{year}-03-02" for year in range(1988, 2012)))
-        self.assertNoHolidayName(name, range(2012, 2050))
+        self.assertHolidayName(name, (f"{year}-03-02" for year in range(self.start_year, 2012)))
+        self.assertNoHolidayName(name, range(2012, self.end_year))
 
     def test_american_forces_evacuation_day(self):
         name = "عيد إجلاء القوات الأمريكية"
-        self.assertHolidayName(name, (f"{year}-06-11" for year in range(1988, 2012)))
-        self.assertNoHolidayName(name, range(2012, 2050))
+        self.assertHolidayName(name, (f"{year}-06-11" for year in range(self.start_year, 2012)))
+        self.assertNoHolidayName(name, range(2012, self.end_year))
 
     def test_glorious_july_revolution_day(self):
         name = "عيد ثورة يوليو المجيدة"
-        self.assertHolidayName(name, (f"{year}-07-23" for year in range(1988, 2012)))
-        self.assertNoHolidayName(name, range(2012, 2050))
+        self.assertHolidayName(name, (f"{year}-07-23" for year in range(self.start_year, 2012)))
+        self.assertNoHolidayName(name, range(2012, self.end_year))
 
     def test_great_al_fateh_day(self):
         name = "عيد الفاتح العظيم"
-        self.assertHolidayName(name, (f"{year}-09-01" for year in range(1988, 2012)))
-        self.assertNoHolidayName(name, range(2012, 2050))
+        self.assertHolidayName(name, (f"{year}-09-01" for year in range(self.start_year, 2012)))
+        self.assertNoHolidayName(name, range(2012, self.end_year))
 
     def test_anniversary_of_the_february_17_revolution(self):
         name = "ثورة 17 فبراير"
-        self.assertHolidayName(name, (f"{year}-02-17" for year in range(2012, 2050)))
-        self.assertNoHolidayName(name, range(1988, 2012))
+        self.assertHolidayName(name, (f"{year}-02-17" for year in range(2012, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 2012))
 
     def test_labor_day(self):
         name = "عيد العمال"
-        self.assertHolidayName(name, (f"{year}-05-01" for year in range(2012, 2050)))
-        self.assertNoHolidayName(name, range(1988, 2012))
+        self.assertHolidayName(name, (f"{year}-05-01" for year in range(2012, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 2012))
 
     def test_national_environmental_sanitation_day(self):
         name = "يوم وطني للإصحاح البيئي"
-        self.assertHolidayName(name, (f"{year}-08-14" for year in range(2022, 2050)))
-        self.assertNoHolidayName(name, range(1988, 2022))
+        self.assertHolidayName(name, (f"{year}-08-14" for year in range(2022, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 2022))
 
     def test_martyrs_day(self):
         name = "يوم الشهيد"
-        self.assertHolidayName(name, (f"{year}-09-16" for year in range(2012, 2050)))
-        self.assertNoHolidayName(name, range(1988, 2012))
+        self.assertHolidayName(name, (f"{year}-09-16" for year in range(2012, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 2012))
 
     def test_liberation_day(self):
         name = "يوم التحرير"
-        self.assertHolidayName(name, (f"{year}-10-23" for year in range(2012, 2050)))
-        self.assertNoHolidayName(name, range(1988, 2012))
+        self.assertHolidayName(name, (f"{year}-10-23" for year in range(2012, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 2012))
 
     def test_independence_day(self):
         name = "عيد الاستقلال"
-        self.assertHolidayName(name, (f"{year}-12-24" for year in range(2012, 2050)))
-        self.assertNoHolidayName(name, range(1988, 2012))
+        self.assertHolidayName(name, (f"{year}-12-24" for year in range(2012, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 2012))
 
     def test_islamic_new_year(self):
         name = "عيد رأس السنة الهجرية"
@@ -88,10 +90,10 @@ class TestLibya(CommonCountryTests, TestCase):
             "2024-07-07",
             "2025-06-26",
         )
-        self.assertHolidayName(name, self.no_estimated_holidays, range(2012, 2050))
-        self.assertNoHolidayName(name, self.no_estimated_holidays, range(1988, 2012))
-        self.assertHolidayName(name, self.workday_holidays, range(1988, 2012))
-        self.assertNoHolidayName(name, self.workday_holidays, range(2012, 2050))
+        self.assertIslamicNoEstimatedHolidayName(name, range(2012, self.end_year))
+        self.assertNoIslamicNoEstimatedHolidayName(name, range(self.start_year, 2012))
+        self.assertWorkdayIslamicNoEstimatedHolidayName(name, range(self.start_year, 2012))
+        self.assertNoWorkdayIslamicNoEstimatedHolidayName(name, range(2012, self.end_year))
 
     def test_prophets_birthday(self):
         name = "ذكرى المولد النبوي الشريف"
@@ -103,7 +105,7 @@ class TestLibya(CommonCountryTests, TestCase):
             "2023-09-27",
             "2024-09-15",
         )
-        self.assertHolidayName(name, self.no_estimated_holidays, range(1988, 2050))
+        self.assertIslamicNoEstimatedHolidayName(name, self.full_range)
 
     def test_eid_al_fitr(self):
         name = "عيد الفطر"
@@ -119,7 +121,7 @@ class TestLibya(CommonCountryTests, TestCase):
             "2025-04-01",
             "2025-04-02",
         )
-        self.assertHolidayName(name, self.no_estimated_holidays, range(1988, 2050))
+        self.assertIslamicNoEstimatedHolidayName(name, self.full_range)
 
     def test_day_of_arafah(self):
         name = "يوم عرفة"
@@ -132,7 +134,7 @@ class TestLibya(CommonCountryTests, TestCase):
             "2024-06-15",
             "2025-06-05",
         )
-        self.assertHolidayName(name, self.no_estimated_holidays, range(1988, 2050))
+        self.assertIslamicNoEstimatedHolidayName(name, self.full_range)
 
     def test_eid_al_adha(self):
         name = "عيد الأضحى"
@@ -148,84 +150,81 @@ class TestLibya(CommonCountryTests, TestCase):
             "2025-06-07",
             "2025-06-08",
         )
-        self.assertHolidayName(name, self.no_estimated_holidays, range(1988, 2050))
+        self.assertIslamicNoEstimatedHolidayName(name, self.full_range)
 
     def test_syrian_revolution_day(self):
         name = "عيد ثورة سوريا"
         self.assertNoHolidayName(name)
-        self.assertHolidayName(
-            name, self.workday_holidays, (f"{year}-03-08" for year in range(1988, 2012))
+        self.assertWorkdayHolidayName(
+            name, (f"{year}-03-08" for year in range(self.start_year, 2012))
         )
-        self.assertNoHolidayName(name, self.workday_holidays, range(2012, 2050))
+        self.assertNoWorkdayHolidayName(name, range(2012, self.end_year))
 
     def test_anniversary_of_arab_league(self):
         name = "ذكرى إنشاء الجامعة العربية"
         self.assertNoHolidayName(name)
-        self.assertHolidayName(
-            name, self.workday_holidays, (f"{year}-03-22" for year in range(1988, 2012))
+        self.assertWorkdayHolidayName(
+            name, (f"{year}-03-22" for year in range(self.start_year, 2012))
         )
-        self.assertNoHolidayName(name, self.workday_holidays, range(2012, 2050))
+        self.assertNoWorkdayHolidayName(name, range(2012, self.end_year))
 
     def test_british_forces_evacuation_day(self):
         name = "عيد إجلاء القوات البريطانية"
         self.assertNoHolidayName(name)
-        self.assertHolidayName(
-            name, self.workday_holidays, (f"{year}-03-28" for year in range(1988, 2012))
+        self.assertWorkdayHolidayName(
+            name, (f"{year}-03-28" for year in range(self.start_year, 2012))
         )
-        self.assertNoHolidayName(name, self.workday_holidays, range(2012, 2050))
+        self.assertNoWorkdayHolidayName(name, range(2012, self.end_year))
 
     def test_italian_forces_evacuation_day(self):
         name = "عيد إجلاء الطليان"
         self.assertNoHolidayName(name)
-        self.assertHolidayName(
-            name, self.workday_holidays, (f"{year}-10-07" for year in range(1988, 2012))
+        self.assertWorkdayHolidayName(
+            name, (f"{year}-10-07" for year in range(self.start_year, 2012))
         )
-        self.assertNoHolidayName(name, self.workday_holidays, range(2012, 2050))
+        self.assertNoWorkdayHolidayName(name, range(2012, self.end_year))
 
     def test_ashura_day(self):
         name = "عاشوراء"
         self.assertNoHolidayName(name)
-        self.assertHolidayName(
+        self.assertWorkdayIslamicNoEstimatedHolidayName(
             name,
-            self.workday_holidays,
             "1988-08-22",
             "1989-08-11",
             "1990-08-01",
             "2010-12-16",
             "2011-12-05",
         )
-        self.assertHolidayName(name, self.workday_holidays, range(1988, 2012))
-        self.assertNoHolidayName(name, self.workday_holidays, range(2012, 2050))
+        self.assertWorkdayIslamicNoEstimatedHolidayName(name, range(self.start_year, 2012))
+        self.assertNoWorkdayIslamicNoEstimatedHolidayName(name, range(2012, self.end_year))
 
     def test_isra_and_miraj_day(self):
         name = "ذكرى الإسراء والمعراج"
         self.assertNoHolidayName(name)
-        self.assertHolidayName(
+        self.assertWorkdayIslamicNoEstimatedHolidayName(
             name,
-            self.workday_holidays,
             "1988-03-15",
             "1989-03-05",
             "1990-02-22",
             "2010-07-09",
             "2011-06-29",
         )
-        self.assertHolidayName(name, self.workday_holidays, range(1988, 2012))
-        self.assertNoHolidayName(name, self.workday_holidays, range(2012, 2050))
+        self.assertWorkdayIslamicNoEstimatedHolidayName(name, range(self.start_year, 2012))
+        self.assertNoWorkdayIslamicNoEstimatedHolidayName(name, range(2012, self.end_year))
 
     def test_night_of_forgiveness(self):
         name = "ليلة النصف من شعبان"
         self.assertNoHolidayName(name)
-        self.assertHolidayName(
+        self.assertWorkdayIslamicNoEstimatedHolidayName(
             name,
-            self.workday_holidays,
             "1988-04-02",
             "1989-03-22",
             "1990-03-12",
             "2010-07-27",
             "2011-07-16",
         )
-        self.assertHolidayName(name, self.workday_holidays, range(1988, 2012))
-        self.assertNoHolidayName(name, self.workday_holidays, range(2012, 2050))
+        self.assertWorkdayIslamicNoEstimatedHolidayName(name, range(self.start_year, 2012))
+        self.assertNoWorkdayIslamicNoEstimatedHolidayName(name, range(2012, self.end_year))
 
     def test_2024(self):
         self.assertHolidaysInYear(
