@@ -21,6 +21,97 @@ class TestLuxembourg(CommonCountryTests, TestCase):
     def setUpClass(cls):
         super().setUpClass(Luxembourg)
 
+    def test_new_years_day(self):
+        self.assertHolidayName("Neijoerschdag", (f"{year}-01-01" for year in self.full_range))
+
+    def test_good_friday(self):
+        name = "Karfreideg"
+        self.assertNoHolidayName(name)
+        self.assertBankHolidayName(
+            name,
+            "2020-04-10",
+            "2021-04-02",
+            "2022-04-15",
+            "2023-04-07",
+            "2024-03-29",
+            "2025-04-18",
+        )
+        self.assertBankHolidayName(name, self.full_range)
+
+    def test_easter_monday(self):
+        name = "Ouschterméindeg"
+        self.assertHolidayName(
+            name,
+            "2020-04-13",
+            "2021-04-05",
+            "2022-04-18",
+            "2023-04-10",
+            "2024-04-01",
+            "2025-04-21",
+        )
+        self.assertHolidayName(name, self.full_range)
+
+    def test_labor_day(self):
+        self.assertHolidayName(
+            "Dag vun der Aarbecht", (f"{year}-05-01" for year in self.full_range)
+        )
+
+    def test_europe_day(self):
+        name = "Europadag"
+        self.assertHolidayName(name, (f"{year}-05-09" for year in range(2019, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 2019))
+
+    def test_ascension_day(self):
+        name = "Christi Himmelfaart"
+        self.assertHolidayName(
+            name,
+            "2020-05-21",
+            "2021-05-13",
+            "2022-05-26",
+            "2023-05-18",
+            "2024-05-09",
+            "2025-05-29",
+        )
+        self.assertHolidayName(name, self.full_range)
+
+    def test_whit_monday(self):
+        name = "Péngschtméindeg"
+        self.assertHolidayName(
+            name,
+            "2020-06-01",
+            "2021-05-24",
+            "2022-06-06",
+            "2023-05-29",
+            "2024-05-20",
+            "2025-06-09",
+        )
+        self.assertHolidayName(name, self.full_range)
+
+    def test_national_day(self):
+        self.assertHolidayName("Nationalfeierdag", (f"{year}-06-23" for year in self.full_range))
+
+    def test_assumption_day(self):
+        self.assertHolidayName("Léiffrawëschdag", (f"{year}-08-15" for year in self.full_range))
+
+    def test_all_saints_day(self):
+        self.assertHolidayName("Allerhellgen", (f"{year}-11-01" for year in self.full_range))
+
+    def test_christmas_eve(self):
+        name = "Hellegowend (nomëtteg)"
+        self.assertNoHolidayName(name)
+        self.assertBankHolidayName(name, (f"{year}-12-24" for year in self.full_range))
+
+    def test_christmas_day(self):
+        self.assertHolidayName("Chrëschtdag", (f"{year}-12-25" for year in self.full_range))
+
+    def test_saint_stephens_day(self):
+        self.assertHolidayName("Stiefesdag", (f"{year}-12-26" for year in self.full_range))
+
+    def test_new_years_eve(self):
+        name = "Silvester"
+        self.assertNoHolidayName(name)
+        self.assertBankHolidayName(name, (f"{year}-12-31" for year in self.full_range))
+
     def test_2018(self):
         self.assertHolidaysInYear(
             2018,
