@@ -20,15 +20,12 @@ from tests.common import CommonCountryTests
 class TestPhilippines(CommonCountryTests, TestCase):
     @classmethod
     def setUpClass(cls):
-        super().setUpClass(Philippines, years=range(1988, 2050))
-        cls.no_estimated_holidays = Philippines(
-            years=range(1988, 2050), islamic_show_estimated=False
-        )
+        super().setUpClass(Philippines)
 
     def test_no_holidays(self):
         super().test_no_holidays()
 
-        self.assertNoHolidays(Philippines(years=2008, categories=WORKDAY))
+        self.assertNoHolidays(Philippines(categories=WORKDAY, years=range(self.start_year, 2009)))
 
     def test_special_holidays(self):
         self.assertHoliday(
@@ -76,7 +73,7 @@ class TestPhilippines(CommonCountryTests, TestCase):
         )
 
     def test_new_years_day(self):
-        self.assertHolidayName("New Year's Day", (f"{year}-01-01" for year in range(1988, 2050)))
+        self.assertHolidayName("New Year's Day", (f"{year}-01-01" for year in self.full_range))
 
     def test_chinese_new_year(self):
         name = "Chinese New Year"
@@ -97,9 +94,10 @@ class TestPhilippines(CommonCountryTests, TestCase):
             "2025-01-29",
             "2026-02-17",
         )
-        self.assertNoHolidayName(name, range(1988, 2012), 2023)
+        self.assertHolidayName(name, range(2012, 2023), range(2024, self.end_year))
+        self.assertNoHolidayName(name, range(self.start_year, 2012), 2023)
 
-    def test_edsa_revolution(self):
+    def test_edsa_people_power_revolution_anniversary(self):
         name = "EDSA People Power Revolution Anniversary"
         self.assertHolidayName(
             name,
@@ -107,81 +105,73 @@ class TestPhilippines(CommonCountryTests, TestCase):
             "2016-02-25",
             "2023-02-24",
         )
-        self.assertHolidayName(
-            name,
-            Philippines(categories=WORKDAY, years=range(2025, 2050)),
-            (f"{year}-02-25" for year in range(2025, 2050)),
+        self.assertNoHolidayName(
+            name, range(self.start_year, 2016), 2017, range(2024, self.end_year)
         )
-        self.assertNoHolidayName(name, range(1988, 2016), 2017, range(2024, 2050))
+        self.assertWorkdayHolidayName(
+            name, (f"{year}-02-25" for year in range(2025, self.end_year))
+        )
+        self.assertNoWorkdayHolidayName(name, range(self.start_year, 2025))
 
     def test_maundy_thursday(self):
         name = "Maundy Thursday"
         self.assertHolidayName(
             name,
-            "2016-03-24",
-            "2017-04-13",
-            "2018-03-29",
-            "2019-04-18",
             "2020-04-09",
             "2021-04-01",
             "2022-04-14",
             "2023-04-06",
             "2024-03-28",
+            "2025-04-17",
         )
-        self.assertHolidayName(name, range(1988, 2050))
+        self.assertHolidayName(name, self.full_range)
 
     def test_good_friday(self):
         name = "Good Friday"
         self.assertHolidayName(
             name,
-            "2016-03-25",
-            "2017-04-14",
-            "2018-03-30",
-            "2019-04-19",
             "2020-04-10",
             "2021-04-02",
             "2022-04-15",
             "2023-04-07",
             "2024-03-29",
+            "2025-04-18",
         )
-        self.assertHolidayName(name, range(1988, 2050))
+        self.assertHolidayName(name, self.full_range)
 
     def test_black_saturday(self):
         name = "Black Saturday"
         self.assertHolidayName(
             name,
-            "2016-03-26",
-            "2017-04-15",
-            "2018-03-31",
-            "2019-04-20",
             "2020-04-11",
             "2021-04-03",
             "2022-04-16",
             "2023-04-08",
             "2024-03-30",
+            "2025-04-19",
         )
-        self.assertHolidayName(name, range(2013, 2050))
-        self.assertNoHolidayName(name, range(1988, 2013))
+        self.assertHolidayName(name, range(2013, self.end_year))
+        self.assertNoHolidayName(name, range(self.start_year, 2013))
 
     def test_day_of_valor(self):
-        name = "Araw ng Kagitingan"
-        years_non_apr_9 = {2008, 2009, 2023}
         self.assertHolidayName(
-            name,
-            (f"{year}-04-09" for year in set(range(1988, 2050)) - years_non_apr_9),
+            "Araw ng Kagitingan",
+            (f"{year}-04-09" for year in set(self.full_range) - {2008, 2009, 2023}),
             "2008-04-07",
             "2009-04-06",
             "2023-04-10",
         )
 
     def test_labor_day(self):
-        self.assertHolidayName("Labor Day", (f"{year}-05-01" for year in range(1988, 2050)))
+        self.assertHolidayName("Labor Day", (f"{year}-05-01" for year in self.full_range))
 
     def test_independence_day(self):
-        name = "Independence Day"
         self.assertHolidayName(
-            name,
-            (f"{year}-06-12" for year in (*range(1988, 2007), *range(2011, 2050))),
+            "Independence Day",
+            (
+                f"{year}-06-12"
+                for year in (*range(self.start_year, 2007), *range(2011, self.end_year))
+            ),
             "2007-06-11",
             "2008-06-09",
             "2009-06-12",
@@ -192,25 +182,27 @@ class TestPhilippines(CommonCountryTests, TestCase):
         # 2025 special non-working day is marked as an additional entry for now,
         # not part of this test case.
         name = "Founding Anniversary of Iglesia ni Cristo"
-        self.assertHolidayName(
+        self.assertNoHolidayName(name)
+        self.assertWorkdayHolidayName(
             name,
-            Philippines(categories=WORKDAY, years=range(2009, 2050)),
-            (f"{year}-07-27" for year in (*range(2009, 2025), *range(2026, 2050))),
+            (f"{year}-07-27" for year in (*range(2009, 2025), *range(2026, self.end_year))),
         )
-        self.assertNoHolidayName(name, range(1988, 2050))
+        self.assertNoWorkdayHolidayName(name, range(self.start_year, 2009), 2025)
 
     def test_ninoy_aquino_day(self):
         name = "Ninoy Aquino Day"
-        years_non_aug_21 = {2007, 2008, 2010, 2024}
         self.assertHolidayName(
             name,
-            (f"{year}-08-21" for year in set(range(2004, 2050)) - years_non_aug_21),
+            (
+                f"{year}-08-21"
+                for year in set(range(2004, self.end_year)) - {2007, 2008, 2010, 2024}
+            ),
             "2007-08-20",
             "2008-08-18",
             "2010-08-23",
             "2024-08-23",
         )
-        self.assertNoHolidayName(name, range(1988, 2004))
+        self.assertNoHolidayName(name, range(self.start_year, 2004))
 
     def test_national_heroes_day(self):
         name = "National Heroes Day"
@@ -231,18 +223,21 @@ class TestPhilippines(CommonCountryTests, TestCase):
             "2023-08-28",
             "2024-08-26",
         )
-        self.assertHolidayName(name, range(1988, 2050))
+        self.assertHolidayName(name, self.full_range)
 
     def test_all_saints_day(self):
-        self.assertHolidayName("All Saints' Day", (f"{year}-11-01" for year in range(1988, 2050)))
+        self.assertHolidayName("All Saints' Day", (f"{year}-11-01" for year in self.full_range))
 
     def test_bonifacio_day(self):
-        name = "Bonifacio Day"
         self.assertHolidayName(
-            name,
+            "Bonifacio Day",
             (
                 f"{year}-11-30"
-                for year in (*range(1988, 2008), *range(2011, 2023), *range(2024, 2050))
+                for year in (
+                    *range(self.start_year, 2008),
+                    *range(2011, 2023),
+                    *range(2024, self.end_year),
+                )
             ),
             "2008-12-01",
             "2009-11-30",
@@ -252,24 +247,30 @@ class TestPhilippines(CommonCountryTests, TestCase):
 
     def test_immaculate_conception_day(self):
         name = "Feast of the Immaculate Conception of Mary"
-        self.assertHolidayName(name, (f"{year}-12-08" for year in range(2019, 2050)))
-        self.assertNoHolidayName(name, range(1988, 2019))
+        self.assertHolidayName(name, (f"{year}-12-08" for year in range(2019, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 2019))
 
     def test_christmas_day(self):
-        self.assertHolidayName("Christmas Day", (f"{year}-12-25" for year in range(1988, 2050)))
+        self.assertHolidayName("Christmas Day", (f"{year}-12-25" for year in self.full_range))
 
     def test_rizal_day(self):
-        name = "Rizal Day"
         self.assertHolidayName(
-            name,
-            (f"{year}-12-30" for year in (*range(1988, 2010), *range(2011, 2050))),
+            "Rizal Day",
+            (
+                f"{year}-12-30"
+                for year in (*range(self.start_year, 2010), *range(2011, self.end_year))
+            ),
             "2010-12-27",
         )
 
     def test_last_day_of_year(self):
         name = "Last Day of the Year"
         self.assertHolidayName(
-            name, (f"{year}-12-31" for year in (*range(1988, 2021), *range(2023, 2050)))
+            name,
+            (
+                f"{year}-12-31"
+                for year in (*range(self.start_year, 2021), *range(2023, self.end_year))
+            ),
         )
         self.assertNoHolidayName(name, 2021, 2022)
 
@@ -277,10 +278,6 @@ class TestPhilippines(CommonCountryTests, TestCase):
         name = "Eid'l Fitr"
         self.assertHolidayName(
             name,
-            "2016-07-07",
-            "2017-06-26",
-            "2018-06-15",
-            "2019-06-05",
             "2020-05-25",
             "2021-05-13",
             "2022-05-03",
@@ -288,17 +285,13 @@ class TestPhilippines(CommonCountryTests, TestCase):
             "2024-04-10",
             "2025-04-01",
         )
-        self.assertHolidayName(name, self.no_estimated_holidays, range(2002, 2050))
-        self.assertNoHolidayName(name, self.no_estimated_holidays, range(1988, 2002))
+        self.assertIslamicNoEstimatedHolidayName(name, range(2002, self.end_year))
+        self.assertNoIslamicNoEstimatedHolidayName(name, range(self.start_year, 2002))
 
     def test_eid_al_adha(self):
         name = "Eid'l Adha"
         self.assertHolidayName(
             name,
-            "2016-09-10",
-            "2017-09-02",
-            "2018-08-21",
-            "2019-08-12",
             "2020-07-31",
             "2021-07-20",
             "2022-07-09",
@@ -306,8 +299,8 @@ class TestPhilippines(CommonCountryTests, TestCase):
             "2024-06-17",
             "2025-06-06",
         )
-        self.assertHolidayName(name, self.no_estimated_holidays, range(2010, 2050))
-        self.assertNoHolidayName(name, self.no_estimated_holidays, range(1988, 2010))
+        self.assertIslamicNoEstimatedHolidayName(name, range(2010, self.end_year))
+        self.assertNoIslamicNoEstimatedHolidayName(name, range(self.start_year, 2010))
 
     def test_2018(self):
         self.assertHolidaysInYear(
