@@ -12,7 +12,6 @@
 
 from unittest import TestCase
 
-from holidays.constants import BANK
 from holidays.countries.qatar import Qatar
 from tests.common import CommonCountryTests
 
@@ -20,15 +19,7 @@ from tests.common import CommonCountryTests
 class TestQatar(CommonCountryTests, TestCase):
     @classmethod
     def setUpClass(cls):
-        years = range(1971, 2050)
-        super().setUpClass(Qatar, years=years)
-        cls.no_estimated_holidays = Qatar(years=years, islamic_show_estimated=False)
-        cls.bank_holidays = Qatar(categories=BANK, years=years)
-
-    def test_no_holidays(self):
-        super().test_no_holidays()
-
-        self.assertNoHolidays(Qatar(categories=BANK, years=1970))
+        super().setUpClass(Qatar)
 
     def test_special_holidays(self):
         self.assertHoliday(
@@ -37,7 +28,8 @@ class TestQatar(CommonCountryTests, TestCase):
 
     def test_sports_day(self):
         name = "اليوم الوطني للرياضة"
-        dts = (
+        self.assertHolidayName(
+            name,
             "2012-02-14",
             "2013-02-12",
             "2014-02-11",
@@ -58,24 +50,18 @@ class TestQatar(CommonCountryTests, TestCase):
             "2029-02-13",
             "2030-02-12",
         )
-        self.assertHolidayName(name, dts)
-        self.assertHolidayName(name, range(2012, 2050))
-        self.assertNoHolidayName(name, range(1971, 2011))
+        self.assertHolidayName(name, range(2012, self.end_year))
+        self.assertNoHolidayName(name, range(self.start_year, 2012))
 
-    def test_national_day(self):
+    def test_qatar_national_day(self):
         name = "اليوم الوطني لقطر"
-        self.assertHolidayName(name, (f"{year}-12-18" for year in range(2007, 2050)))
-        self.assertNoHolidayName(name, range(1971, 2007))
+        self.assertHolidayName(name, (f"{year}-12-18" for year in range(2007, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 2007))
 
     def test_eid_al_fitr(self):
         name = "عيد الفطر"
-        dts = (
-            "2018-06-15",
-            "2018-06-16",
-            "2018-06-17",
-            "2019-06-04",
-            "2019-06-05",
-            "2019-06-06",
+        self.assertHolidayName(
+            name,
             "2020-05-24",
             "2020-05-25",
             "2020-05-26",
@@ -95,18 +81,12 @@ class TestQatar(CommonCountryTests, TestCase):
             "2025-03-31",
             "2025-04-01",
         )
-        self.assertHolidayName(name, dts)
-        self.assertHolidayName(name, self.no_estimated_holidays, range(1971, 2050))
+        self.assertIslamicNoEstimatedHolidayName(name, self.full_range)
 
     def test_eid_al_adha(self):
         name = "عيد الأضحى"
-        dts = (
-            "2018-08-22",
-            "2018-08-23",
-            "2018-08-24",
-            "2019-08-11",
-            "2019-08-12",
-            "2019-08-13",
+        self.assertHolidayName(
+            name,
             "2020-07-31",
             "2020-08-01",
             "2020-08-02",
@@ -122,30 +102,22 @@ class TestQatar(CommonCountryTests, TestCase):
             "2024-06-16",
             "2024-06-17",
             "2024-06-18",
+            "2025-06-06",
+            "2025-06-07",
+            "2025-06-08",
         )
-        self.assertHolidayName(name, dts)
-        self.assertHolidayName(name, self.no_estimated_holidays, range(1971, 2050))
+        self.assertIslamicNoEstimatedHolidayName(name, self.full_range)
 
     def test_new_years_day(self):
         name = "رأس السنة الميلادية"
-        self.assertHolidayName(
-            name, self.bank_holidays, (f"{year}-01-01" for year in range(1971, 2050))
-        )
         self.assertNoHolidayName(name)
+        self.assertBankHolidayName(name, (f"{year}-01-01" for year in self.full_range))
 
     def test_march_bank_holiday(self):
         name = "عطلة البنك"
-        dts = (
-            "2010-03-07",
-            "2011-03-06",
-            "2012-03-04",
-            "2013-03-03",
-            "2014-03-02",
-            "2015-03-01",
-            "2016-03-06",
-            "2017-03-05",
-            "2018-03-04",
-            "2019-03-03",
+        self.assertNoHolidayName(name)
+        self.assertBankHolidayName(
+            name,
             "2020-03-01",
             "2021-03-07",
             "2022-03-06",
@@ -153,10 +125,8 @@ class TestQatar(CommonCountryTests, TestCase):
             "2024-03-03",
             "2025-03-02",
         )
-        self.assertHolidayName(name, self.bank_holidays, dts)
-        self.assertHolidayName(name, self.bank_holidays, range(2010, 2050))
-        self.assertNoHolidayName(name, self.bank_holidays, range(1971, 2010))
-        self.assertNoHolidayName(name)
+        self.assertBankHolidayName(name, range(2010, self.end_year))
+        self.assertNoBankHolidayName(name, range(self.start_year, 2010))
 
     def test_weekend(self):
         for dt in (
