@@ -12,7 +12,7 @@
 
 from unittest import TestCase
 
-from holidays.countries.saudi_arabia import SaudiArabia, SA, SAU
+from holidays.countries.saudi_arabia import SaudiArabia
 from tests.common import CommonCountryTests
 
 
@@ -22,9 +22,6 @@ class TestSaudiArabia(CommonCountryTests, TestCase):
         years = range(1950, 2050)
         super().setUpClass(SaudiArabia, years=years, years_non_observed=years)
 
-    def test_country_aliases(self):
-        self.assertAliases(SaudiArabia, SA, SAU)
-
     def test_special_holidays(self):
         self.assertHoliday("2022-11-23")
 
@@ -181,8 +178,8 @@ class TestSaudiArabia(CommonCountryTests, TestCase):
             self.assertFalse(self.holidays.is_weekend(dt))
 
     def test_2022(self):
-        self.assertHolidays(
-            SaudiArabia(years=2022),
+        self.assertHolidaysInYear(
+            2022,
             ("2022-02-22", "يوم التأسيسي"),
             ("2022-05-01", "عطلة عيد الفطر"),
             ("2022-05-02", "عطلة عيد الفطر"),
