@@ -21,12 +21,7 @@ from tests.common import CommonCountryTests
 class TestSouthKorea(CommonCountryTests, TestCase):
     @classmethod
     def setUpClass(cls):
-        super().setUpClass(SouthKorea, years=range(1948, 2050))
-
-    def test_no_holidays(self):
-        super().test_no_holidays()
-
-        self.assertNoHolidays(SouthKorea(categories=BANK, years=1947))
+        super().setUpClass(SouthKorea)
 
     def test_special_holidays(self):
         # Election Dates have its own separate checklists.
@@ -191,81 +186,63 @@ class TestSouthKorea(CommonCountryTests, TestCase):
 
     def test_new_years_day(self):
         name = "신정연휴"
-        self.assertHolidayName(name, (f"{year}-01-01" for year in range(1949, 2050)))
-        self.assertHolidayName(name, (f"{year}-01-02" for year in range(1949, 1999)))
-        self.assertHolidayName(name, (f"{year}-01-03" for year in range(1949, 1990)))
-        self.assertNoHoliday(f"{year}-01-02" for year in range(1999, 2050))
-        self.assertNoHoliday(f"{year}-01-03" for year in range(1990, 2050))
-
-    def test_korean_new_years_day(self):
-        name = "설날"
-        name_old = "민속의 날"
-        self.assertHolidayName(
-            f"{name} 전날",
-            "2014-01-30",
-            "2015-02-18",
-            "2016-02-07",
-            "2017-01-27",
-            "2018-02-15",
-            "2019-02-04",
-            "2020-01-24",
-            "2021-02-11",
-            "2022-01-31",
-            "2023-01-21",
-        )
-
         self.assertHolidayName(
             name,
-            "1997-02-08",
-            "2008-02-07",
-            "2009-01-26",
-            "2010-02-14",
-            "2011-02-03",
-            "2012-01-23",
-            "2013-02-10",
-            "2014-01-31",
-            "2015-02-19",
-            "2016-02-08",
-            "2017-01-28",
-            "2018-02-16",
-            "2019-02-05",
-            "2020-01-25",
-            "2021-02-12",
-            "2022-02-01",
-            "2023-01-22",
+            (f"{year}-01-01" for year in self.full_range),
+            (f"{year}-01-02" for year in range(self.start_year, 1999)),
+            (f"{year}-01-03" for year in range(self.start_year, 1990)),
         )
+        self.assertNoHolidayName(
+            name,
+            (f"{year}-01-02" for year in range(1999, self.end_year)),
+            (f"{year}-01-03" for year in range(1990, self.end_year)),
+        )
+
+    def test_korean_new_years_day(self):
+        name_1985 = "민속의 날"
+        name_1989 = "설날"
+        name_1989_eve = f"{name_1989} 전날"
+        name_1989_day2 = f"{name_1989} 다음날"
+        name_1989_observed = f"{name_1989} 대체 휴일"
         self.assertHolidayName(
-            name_old,
+            name_1985,
             "1985-02-20",
             "1986-02-09",
             "1987-01-29",
             "1988-02-18",
         )
-
         self.assertHolidayName(
-            f"{name} 다음날",
-            "2006-01-30",
-            "2007-02-19",
-            "2008-02-08",
-            "2009-01-27",
-            "2010-02-15",
-            "2011-02-04",
-            "2012-01-24",
-            "2013-02-11",
-            "2014-02-01",
-            "2015-02-20",
-            "2016-02-09",
-            "2017-01-29",
-            "2018-02-17",
-            "2019-02-06",
+            name_1989,
+            "2020-01-25",
+            "2021-02-12",
+            "2022-02-01",
+            "2023-01-22",
+            "2024-02-10",
+            "2025-01-29",
+        )
+        self.assertHolidayName(name_1989, range(1989, self.end_year))
+        self.assertHolidayName(
+            name_1989_eve,
+            "2020-01-24",
+            "2021-02-11",
+            "2022-01-31",
+            "2023-01-21",
+            "2024-02-09",
+            "2025-01-28",
+        )
+        self.assertHolidayName(name_1989_eve, range(1989, self.end_year))
+        self.assertHolidayName(
+            name_1989_day2,
             "2020-01-26",
             "2021-02-13",
             "2022-02-02",
             "2023-01-23",
+            "2024-02-11",
+            "2025-01-30",
         )
-
+        self.assertHolidayName(name_1989_day2, range(1989, self.end_year))
         self.assertHolidayName(
-            f"{name} 대체 휴일",
+            name_1989_observed,
             "2016-02-10",
             "2017-01-30",
             "2020-01-27",
@@ -273,21 +250,20 @@ class TestSouthKorea(CommonCountryTests, TestCase):
             "2024-02-12",
             "2027-02-09",
         )
-
-        self.assertNoHoliday("2015-02-07", "2015-02-21")
-        self.assertNoHolidayName(f"{name} 전날", range(1985, 1989))
-        self.assertNoHolidayName(f"{name} 다음날", range(1985, 1989))
-        self.assertNoHolidayName(f"{name} 대체 휴일", range(1985, 2014))
-
-        self.assertNoHolidayName(name_old, range(1949, 1985), range(1989, 2050))
-        self.assertNoHolidayName(f"{name_old} 전날", range(1949, 2050))
-        self.assertNoHolidayName(f"{name_old} 다음날", range(1949, 2050))
-        self.assertNoHolidayName(f"{name_old} 대체 휴일", range(1949, 2050))
+        self.assertNoHolidayName(
+            name_1985, range(self.start_year, 1985), range(1989, self.end_year)
+        )
+        self.assertNoHolidayName(f"{name_1985} 전날")
+        self.assertNoHolidayName(f"{name_1985} 다음날")
+        self.assertNoHolidayName(f"{name_1985} 대체 휴일")
+        self.assertNoHolidayName(name_1989, range(self.start_year, 1989))
+        self.assertNoHolidayName(name_1989_eve, range(self.start_year, 1989))
+        self.assertNoHolidayName(name_1989_day2, range(self.start_year, 1989))
+        self.assertNoHolidayName(name_1989_observed, range(self.start_year, 2014))
 
     def test_independence_movement_day(self):
         name = "삼일절"
-        self.assertHolidayName(name, (f"{year}-03-01" for year in range(1949, 2050)))
-
+        self.assertHolidayName(name, (f"{year}-03-01" for year in self.full_range))
         self.assertHolidayName(
             f"{name} 대체 휴일",
             "2025-03-03",
@@ -299,16 +275,18 @@ class TestSouthKorea(CommonCountryTests, TestCase):
         self.assertHolidayName(
             name, (f"{year}-04-05" for year in (*range(1949, 1960), *range(1961, 2006)))
         )
-        self.assertNoHolidayName(name, 1948, 1960, range(2006, 2050))
+        self.assertNoHolidayName(
+            name, range(self.start_year, 1949), 1960, range(2006, self.end_year)
+        )
         self.assertHolidayName(f"{name} 대체 휴일", "1959-04-06")
 
     def test_childrens_day(self):
         name = "어린이날"
-        self.assertHolidayName(name, (f"{year}-05-05" for year in range(1975, 2050)))
-        self.assertNoHolidayName(name, 1974)
-
+        name_observed = f"{name} 대체 휴일"
+        self.assertHolidayName(name, (f"{year}-05-05" for year in range(1975, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 1975))
         self.assertHolidayName(
-            f"{name} 대체 휴일",
+            name_observed,
             "2018-05-07",
             "2019-05-06",
             "2024-05-06",
@@ -316,13 +294,29 @@ class TestSouthKorea(CommonCountryTests, TestCase):
             "2029-05-07",
             "2030-05-06",
         )
-        self.assertNoHolidayName(f"{name} 대체 휴일", range(1975, 2014))
+        self.assertNoHolidayName(name_observed, range(1975, 2014))
 
-    def test_birthday_of_buddha(self):  # ???
-        name = "부처님오신날"
-        name_old = "석가탄신일"
+    def test_buddhas_birthday(self):
+        name_1975 = "석가탄신일"
+        name_2017 = "부처님오신날"
+        name_2017_observed = f"{name_2017} 대체 휴일"
         self.assertHolidayName(
-            name,
+            name_1975,
+            "2006-05-05",
+            "2007-05-24",
+            "2008-05-12",
+            "2009-05-02",
+            "2010-05-21",
+            "2011-05-10",
+            "2012-05-28",
+            "2013-05-17",
+            "2014-05-06",
+            "2015-05-25",
+            "2016-05-14",
+        )
+        self.assertHolidayName(name_1975, range(1975, 2017))
+        self.assertHolidayName(
+            name_2017,
             "2017-05-03",
             "2018-05-22",
             "2019-05-12",
@@ -337,121 +331,83 @@ class TestSouthKorea(CommonCountryTests, TestCase):
             "2028-05-02",
             "2029-05-20",
         )
+        self.assertHolidayName(name_2017, range(2017, self.end_year))
         self.assertHolidayName(
-            name_old,
-            "2006-05-05",
-            "2007-05-24",
-            "2008-05-12",
-            "2009-05-02",
-            "2010-05-21",
-            "2011-05-10",
-            "2012-05-28",
-            "2013-05-17",
-            "2014-05-06",
-            "2015-05-25",
-            "2016-05-14",
-        )
-
-        self.assertHolidayName(
-            f"{name} 대체 휴일",
+            name_2017_observed,
             "2023-05-29",
             "2026-05-25",
             "2029-05-21",
         )
-
-        self.assertNoHoliday("2022-05-09")
-        self.assertNoHolidayName(name, 1974)
-        self.assertNoHolidayName(name_old, 1974)
-        self.assertNoHolidayName(f"{name} 대체 휴일", range(1975, 2023))
-        self.assertNoHolidayName(f"{name_old} 대체 휴일", range(1975, 2023))
+        self.assertNoHolidayName(
+            name_1975, range(self.start_year, 1975), range(2017, self.end_year)
+        )
+        self.assertNoHolidayName(f"{name_1975} 대체 휴일")
+        self.assertNoHolidayName(name_2017, range(self.start_year, 2017))
+        self.assertNoHolidayName(name_2017_observed, range(self.start_year, 2023))
 
     def test_memorial_day(self):
         name = "현충일"
-        self.assertNoHolidayName(name, range(1948, 1956))
-        self.assertHolidayName(name, (f"{year}-06-06" for year in range(1956, 2050)))
+        self.assertHolidayName(name, (f"{year}-06-06" for year in range(1956, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 1956))
 
     def test_constitution_day(self):
         name = "제헌절"
-        self.assertHolidayName(name, (f"{year}-07-17" for year in range(1949, 2008)))
-        self.assertNoHoliday(f"{year}-07-17" for year in range(2008, 2050))
-        self.assertNoHolidayName(name, range(2008, 2050))
-
+        self.assertHolidayName(name, (f"{year}-07-17" for year in range(self.start_year, 2008)))
+        self.assertNoHolidayName(name, range(2008, self.end_year))
         self.assertHolidayName(f"{name} 대체 휴일", "1960-07-18")
 
     def test_liberation_day(self):
         name = "광복절"
-        self.assertHolidayName(name, (f"{year}-08-15" for year in range(1949, 2050)))
-
+        name_observed = f"{name} 대체 휴일"
+        self.assertHolidayName(name, (f"{year}-08-15" for year in self.full_range))
         self.assertHolidayName(
-            f"{name} 대체 휴일",
+            name_observed,
             "2021-08-16",
             "2026-08-17",
             "2027-08-16",
         )
-        self.assertNoHolidayName(f"{name} 대체 휴일", range(1949, 2021))
+        self.assertNoHolidayName(name_observed, range(self.start_year, 2021))
 
     def test_chuseok(self):
         name = "추석"
-        self.assertHolidayName(
-            f"{name} 전날",
-            "2014-09-07",
-            "2015-09-26",
-            "2016-09-14",
-            "2017-10-03",
-            "2018-09-23",
-            "2019-09-12",
-            "2020-09-30",
-            "2021-09-20",
-            "2022-09-09",
-            "2023-09-28",
-        )
-
+        name_eve = f"{name} 전날"
+        name_day2 = f"{name} 다음날"
+        name_observed = f"{name} 대체 휴일"
         self.assertHolidayName(
             name,
-            "1985-09-29",
-            "1986-09-18",
-            "1987-10-07",
-            "1988-09-25",
-            "1978-09-17",
-            "2010-09-22",
-            "2011-09-12",
-            "2012-09-30",
-            "2013-09-19",
-            "2014-09-08",
-            "2015-09-27",
-            "2016-09-15",
-            "2017-10-04",
-            "2018-09-24",
-            "2019-09-13",
             "2020-10-01",
             "2021-09-21",
             "2022-09-10",
             "2023-09-29",
+            "2024-09-17",
+            "2025-10-06",
         )
-
+        self.assertHolidayName(name, self.full_range)
         self.assertHolidayName(
-            f"{name} 다음날",
+            name_eve,
+            "2020-09-30",
+            "2021-09-20",
+            "2022-09-09",
+            "2023-09-28",
+            "2024-09-16",
+            "2025-10-05",
+        )
+        self.assertHolidayName(name_eve, range(1989, self.end_year))
+        self.assertHolidayName(
+            name_day2,
             "1986-09-19",
             "1987-10-08",
             "1988-09-26",
-            "2010-09-23",
-            "2011-09-13",
-            "2012-10-01",
-            "2013-09-20",
-            "2014-09-09",
-            "2015-09-28",
-            "2016-09-16",
-            "2017-10-05",
-            "2018-09-25",
-            "2019-09-14",
             "2020-10-02",
             "2021-09-22",
             "2022-09-11",
             "2023-09-30",
+            "2024-09-18",
+            "2025-10-07",
         )
-
+        self.assertHolidayName(name_day2, range(1986, self.end_year))
         self.assertHolidayName(
-            f"{name} 대체 휴일",
+            name_observed,
             "2014-09-10",
             "2015-09-29",
             "2018-09-26",
@@ -459,72 +415,73 @@ class TestSouthKorea(CommonCountryTests, TestCase):
             "2025-10-08",
             "2029-09-24",
         )
-
-        self.assertNoHolidayName(f"{name} 전날", range(1949, 1989))
-        self.assertNoHolidayName(f"{name} 다음날", range(1949, 1986))
-        self.assertNoHolidayName(f"{name} 대체 휴일", range(1949, 2014))
+        self.assertNoHolidayName(name_eve, range(self.start_year, 1989))
+        self.assertNoHolidayName(name_day2, range(self.start_year, 1986))
+        self.assertNoHolidayName(name_observed, range(self.start_year, 2014))
 
     def test_armed_forces_day(self):
         name = "국군의 날"
+        name_observed = f"{name} 대체 휴일"
         self.assertHolidayName(name, (f"{year}-10-01" for year in range(1976, 1991)))
-
-        self.assertHolidayName(f"{name} 대체 휴일", "1989-10-02")
-        self.assertNoHolidayName(f"{name} 대체 휴일", range(1976, 1989), range(1990, 1992))
+        self.assertHolidayName(name_observed, "1989-10-02")
+        self.assertNoHolidayName(name_observed, range(1976, 1989), range(1990, 1992))
 
     def test_national_foundation_day(self):
         name = "개천절"
-        self.assertHolidayName(name, (f"{year}-10-03" for year in range(1949, 2050)))
-
+        name_observed = f"{name} 대체 휴일"
+        self.assertHolidayName(name, (f"{year}-10-03" for year in self.full_range))
         self.assertHolidayName(
-            f"{name} 대체 휴일",
+            name_observed,
             "2021-10-04",
             "2026-10-05",
             "2027-10-04",
         )
-        self.assertNoHolidayName(f"{name} 대체 휴일", range(1949, 2021))
+        self.assertNoHolidayName(name_observed, range(self.start_year, 2021))
 
     def test_hangul_day(self):
         name = "한글날"
-        self.assertHolidayName(name, (f"{year}-10-09" for year in range(1949, 1991)))
-        self.assertHolidayName(name, (f"{year}-10-09" for year in range(2013, 2050)))
-        self.assertNoHoliday(f"{year}-10-09" for year in range(1991, 2013))
-        self.assertNoHolidayName(name, range(1991, 2013))
-
+        name_observed = f"{name} 대체 휴일"
         self.assertHolidayName(
-            f"{name} 대체 휴일",
+            name,
+            (
+                f"{year}-10-09"
+                for year in (*range(self.start_year, 1991), *range(2013, self.end_year))
+            ),
+        )
+        self.assertNoHolidayName(name, range(1991, 2013))
+        self.assertHolidayName(
+            name_observed,
             "1960-10-10",
             "2021-10-11",
             "2022-10-10",
             "2027-10-11",
         )
-        self.assertNoHolidayName(f"{name} 대체 휴일", range(1949, 1960), range(1961, 2021))
+        self.assertNoHolidayName(name_observed, range(self.start_year, 1960), range(1961, 2021))
 
     def test_united_nations_day(self):
         name = "국제연합일"
         self.assertHolidayName(name, (f"{year}-10-24" for year in range(1950, 1976)))
-        self.assertNoHolidayName(name, 1949, range(1976, 2050))
+        self.assertNoHolidayName(name, range(self.start_year, 1950), range(1976, self.end_year))
 
     def test_christmas_day(self):
         name = "기독탄신일"
-        self.assertHolidayName(name, (f"{year}-12-25" for year in range(1949, 2050)))
-
+        name_observed = f"{name} 대체 휴일"
+        self.assertHolidayName(name, (f"{year}-12-25" for year in self.full_range))
         self.assertHolidayName(
-            f"{name} 대체 휴일",
+            name_observed,
             "1960-12-26",
             "2027-12-27",
             "2032-12-27",
             "2033-12-26",
         )
-
-        self.assertNoHoliday("2022-12-26")
-        self.assertNoHolidayName(f"{name} 대체 휴일", range(1949, 1960), range(1961, 2023))
+        self.assertNoHolidayName(name_observed, range(self.start_year, 1960), range(1961, 2023))
 
     def test_workers_day(self):
-        name = "근로자의날"
-        holidays = SouthKorea(categories=BANK, years=range(1990, 2050))
-        self.assertHolidayName(name, holidays, (f"{year}-03-10" for year in range(1990, 1994)))
-        self.assertHolidayName(name, holidays, (f"{year}-05-01" for year in range(1994, 2050)))
-        self.assertNoHoliday(holidays, "1993-05-01", "1994-03-10")
+        self.assertBankHolidayName(
+            "근로자의날",
+            (f"{year}-03-10" for year in range(self.start_year, 1994)),
+            (f"{year}-05-01" for year in range(1994, self.end_year)),
+        )
 
     def test_korea_deprecation_warning(self):
         warnings.simplefilter("default")
