@@ -12,6 +12,7 @@
 
 from unittest import TestCase
 
+from holidays.constants import ARMED_FORCES, BANK, GOVERNMENT, SCHOOL
 from holidays.countries.thailand import Thailand
 from tests.common import CommonCountryTests
 
@@ -21,8 +22,22 @@ class TestThailand(CommonCountryTests, TestCase):
     def setUpClass(cls):
         super().setUpClass(Thailand)
 
+    def test_no_holidays(self):
+        super().test_no_holidays()
+
+        self.assertNoHolidays(
+            Thailand(categories=ARMED_FORCES, years=range(self.start_year, 1959))
+        )
+        self.assertNoHolidays(
+            Thailand(
+                categories=BANK, years=(*range(self.start_year, 1943), *range(2022, self.end_year))
+            )
+        )
+        self.assertNoHolidays(Thailand(categories=GOVERNMENT, years=range(self.start_year, 1960)))
+        self.assertNoHolidays(Thailand(categories=SCHOOL, years=range(self.start_year, 1957)))
+
     def test_special_holidays(self):
-        dt = (
+        dts = (
             # 1992-1994 (include In Lieus, Checked with Bank of Thailand Data).
             "1992-05-18",
             "1992-12-07",
@@ -98,14 +113,14 @@ class TestThailand(CommonCountryTests, TestCase):
             "2025-08-11",
             "2026-01-02",
         )
-        dt_observed = (
+        obs_dts = (
             "2007-12-24",
             "2020-07-27",
             "2020-09-04",
             "2020-09-07",
         )
-        self.assertHoliday(dt, dt_observed)
-        self.assertNoNonObservedHoliday(dt_observed)
+        self.assertHoliday(dts, obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_new_years_day(self):
         name = "วันขึ้นปีใหม่"
@@ -972,10 +987,8 @@ class TestThailand(CommonCountryTests, TestCase):
             ("2022-07-15", "วันหยุดพิเศษ (เพิ่มเติม)"),
             (
                 "2022-07-28",
-                (
-                    "วันเฉลิมพระชนมพรรษาพระบาทสมเด็จพระปรเมนทรรามาธิบดี"
-                    "ศรีสินทรมหาวชิราลงกรณ พระวชิรเกล้าเจ้าอยู่หัว"
-                ),
+                "วันเฉลิมพระชนมพรรษาพระบาทสมเด็จพระปรเมนทรรามาธิบดี"
+                "ศรีสินทรมหาวชิราลงกรณ พระวชิรเกล้าเจ้าอยู่หัว",
             ),
             ("2022-07-29", "วันหยุดพิเศษ (เพิ่มเติม)"),
             ("2022-08-12", "วันเฉลิมพระชนมพรรษาสมเด็จพระบรมราชชนนีพันปีหลวง; วันแม่แห่งชาติ"),
@@ -991,10 +1004,8 @@ class TestThailand(CommonCountryTests, TestCase):
             ("2022-11-08", "วันลอยกระทง"),
             (
                 "2022-12-05",
-                (
-                    "วันคล้ายวันเฉลิมพระชนมพรรษาพระบาทสมเด็จพระบรม"
-                    "ชนกาธิเบศร มหาภูมิพลอดุลยเดชมหาราช บรมนาถบพิตร; วันชาติ; วันพ่อแห่งชาติ"
-                ),
+                "วันคล้ายวันเฉลิมพระชนมพรรษาพระบาทสมเด็จพระบรม"
+                "ชนกาธิเบศร มหาภูมิพลอดุลยเดชมหาราช บรมนาถบพิตร; วันชาติ; วันพ่อแห่งชาติ",
             ),
             ("2022-12-10", "วันรัฐธรรมนูญ"),
             ("2022-12-12", "ชดเชยวันรัฐธรรมนูญ"),
@@ -1046,10 +1057,8 @@ class TestThailand(CommonCountryTests, TestCase):
             ("2022-11-08", "Loy Krathong"),
             (
                 "2022-12-05",
-                (
-                    "HM King Bhumibol Adulyadej the Great's Birthday; "
-                    "National Day; National Father's Day"
-                ),
+                "HM King Bhumibol Adulyadej the Great's Birthday; National Day; "
+                "National Father's Day",
             ),
             ("2022-12-10", "Constitution Day"),
             ("2022-12-12", "Constitution Day (in lieu)"),
