@@ -12,7 +12,6 @@
 
 from unittest import TestCase
 
-from holidays.constants import OPTIONAL
 from holidays.countries.trinidad_and_tobago import TrinidadAndTobago
 from tests.common import CommonCountryTests
 
@@ -20,27 +19,19 @@ from tests.common import CommonCountryTests
 class TestTrinidadAndTobago(CommonCountryTests, TestCase):
     @classmethod
     def setUpClass(cls):
-        years = range(1963, 2050)
-        super().setUpClass(TrinidadAndTobago, years=years, years_non_observed=years)
-        cls.no_estimated_holidays = TrinidadAndTobago(years=years, islamic_show_estimated=False)
-        cls.optional_holidays = TrinidadAndTobago(categories=OPTIONAL, years=years)
-
-    def test_no_holidays(self):
-        super().test_no_holidays()
-
-        self.assertNoHolidays(TrinidadAndTobago(categories=OPTIONAL, years=1962))
+        super().setUpClass(TrinidadAndTobago)
 
     def test_new_years_day(self):
         name = "New Year's Day"
-        self.assertHolidayName(name, (f"{year}-01-01" for year in range(1963, 2050)))
-        dt = (
+        self.assertHolidayName(name, (f"{year}-01-01" for year in self.full_range))
+        obs_dts = (
             "2006-01-02",
             "2012-01-02",
             "2017-01-02",
             "2023-01-02",
         )
-        self.assertHolidayName(f"{name} (observed)", dt)
-        self.assertNoNonObservedHoliday(dt)
+        self.assertHolidayName(f"{name} (observed)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_good_friday(self):
         name = "Good Friday"
@@ -53,14 +44,14 @@ class TestTrinidadAndTobago(CommonCountryTests, TestCase):
             "2024-03-29",
             "2025-04-18",
         )
-        self.assertHolidayName(name, range(1963, 2050))
-        dt = (
+        self.assertHolidayName(name, self.full_range)
+        obs_dts = (
             "2018-04-03",
             "2029-04-03",
             "2040-04-03",
         )
-        self.assertHolidayName(f"{name} (observed)", dt)
-        self.assertNoNonObservedHoliday(dt)
+        self.assertHolidayName(f"{name} (observed)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_easter_monday(self):
         name = "Easter Monday"
@@ -73,42 +64,42 @@ class TestTrinidadAndTobago(CommonCountryTests, TestCase):
             "2024-04-01",
             "2025-04-21",
         )
-        self.assertHolidayName(name, range(1963, 2050))
-        dt = (
+        self.assertHolidayName(name, self.full_range)
+        obs_dts = (
             "2043-03-31",
             "2054-03-31",
             "2065-03-31",
         )
-        self.assertHolidayName(f"{name} (observed)", dt)
-        self.assertNoNonObservedHoliday(dt)
+        self.assertHolidayName(f"{name} (observed)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_spiritual_baptist_liberation_day(self):
         name = "Spiritual Baptist Liberation Day"
         self.assertHolidayName(name, (f"{year}-03-30" for year in range(1996, 2050)))
         self.assertNoHolidayName(name, range(1963, 1996))
-        dt = (
+        obs_dts = (
             "2003-03-31",
             "2008-03-31",
             "2014-03-31",
             "2018-04-03",
             "2025-04-01",
         )
-        self.assertHolidayName(f"{name} (observed)", dt)
-        self.assertNoNonObservedHoliday(dt)
+        self.assertHolidayName(f"{name} (observed)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_indian_arrival_day(self):
         name = "Indian Arrival Day"
         self.assertHolidayName(name, (f"{year}-05-30" for year in range(1996, 2050)))
         self.assertNoHolidayName(name, range(1963, 1996))
-        dt = (
+        obs_dts = (
             "2004-05-31",
             "2010-05-31",
             "2013-05-31",
             "2021-05-31",
             "2024-05-31",
         )
-        self.assertHolidayName(f"{name} (observed)", dt)
-        self.assertNoNonObservedHoliday(dt)
+        self.assertHolidayName(f"{name} (observed)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_corpus_christi(self):
         name = "Corpus Christi"
@@ -121,21 +112,21 @@ class TestTrinidadAndTobago(CommonCountryTests, TestCase):
             "2024-05-30",
             "2025-06-19",
         )
-        self.assertHolidayName(name, range(1963, 2050))
-        dt = (
+        self.assertHolidayName(name, self.full_range)
+        obs_dts = (
             "2013-05-31",
             "2014-06-20",
             "2024-05-31",
             "2025-06-20",
         )
-        self.assertHolidayName(f"{name} (observed)", dt)
-        self.assertNoNonObservedHoliday(dt)
+        self.assertHolidayName(f"{name} (observed)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_labor_day(self):
         name = "Labour Day"
         self.assertHolidayName(name, (f"{year}-06-19" for year in range(1973, 2050)))
         self.assertNoHolidayName(name, range(1963, 1973))
-        dt = (
+        obs_dts = (
             "2005-06-20",
             "2011-06-20",
             "2014-06-20",
@@ -143,68 +134,68 @@ class TestTrinidadAndTobago(CommonCountryTests, TestCase):
             "2022-06-20",
             "2025-06-20",
         )
-        self.assertHolidayName(f"{name} (observed)", dt)
-        self.assertNoNonObservedHoliday(dt)
+        self.assertHolidayName(f"{name} (observed)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_african_emancipation_day(self):
         name = "African Emancipation Day"
         self.assertHolidayName(name, (f"{year}-08-01" for year in range(1985, 2050)))
         self.assertNoHolidayName(name, range(1963, 1985))
-        dt = (
+        obs_dts = (
             "2004-08-02",
             "2010-08-02",
             "2021-08-02",
         )
-        self.assertHolidayName(f"{name} (observed)", dt)
-        self.assertNoNonObservedHoliday(dt)
+        self.assertHolidayName(f"{name} (observed)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_independence_day(self):
         name = "Independence Day"
-        self.assertHolidayName(name, (f"{year}-08-31" for year in range(1963, 2050)))
-        dt = (
+        self.assertHolidayName(name, (f"{year}-08-31" for year in self.full_range))
+        obs_dts = (
             "2003-09-01",
             "2008-09-01",
             "2014-09-01",
             "2025-09-01",
         )
-        self.assertHolidayName(f"{name} (observed)", dt)
-        self.assertNoNonObservedHoliday(dt)
+        self.assertHolidayName(f"{name} (observed)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_republic_day(self):
         name = "Republic Day"
         self.assertHolidayName(name, (f"{year}-09-24" for year in range(1976, 2050)))
         self.assertNoHolidayName(name, range(1963, 1976))
-        dt = (
+        obs_dts = (
             "2000-09-25",
             "2006-09-25",
             "2017-09-25",
             "2023-09-25",
         )
-        self.assertHolidayName(f"{name} (observed)", dt)
-        self.assertNoNonObservedHoliday(dt)
+        self.assertHolidayName(f"{name} (observed)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_christmas_day(self):
         name = "Christmas Day"
-        self.assertHolidayName(name, (f"{year}-12-25" for year in range(1963, 2050)))
-        dt = (
+        self.assertHolidayName(name, (f"{year}-12-25" for year in self.full_range))
+        obs_dts = (
             "2005-12-27",
             "2011-12-27",
             "2016-12-27",
             "2022-12-27",
         )
-        self.assertHolidayName(f"{name} (observed)", dt)
-        self.assertNoNonObservedHoliday(dt)
+        self.assertHolidayName(f"{name} (observed)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_boxing_day(self):
         name = "Boxing Day"
-        self.assertHolidayName(name, (f"{year}-12-26" for year in range(1963, 2050)))
-        dt = (
+        self.assertHolidayName(name, (f"{year}-12-26" for year in self.full_range))
+        obs_dts = (
             "2004-12-27",
             "2010-12-27",
             "2021-12-27",
         )
-        self.assertHolidayName(f"{name} (observed)", dt)
-        self.assertNoNonObservedHoliday(dt)
+        self.assertHolidayName(f"{name} (observed)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_diwali(self):
         name = "Divali"
@@ -217,15 +208,15 @@ class TestTrinidadAndTobago(CommonCountryTests, TestCase):
             "2024-10-31",
             "2025-10-20",
         )
-        self.assertHolidayName(name, range(1963, 2050))
-        dt = (
+        self.assertHolidayName(name, self.full_range)
+        obs_dts = (
             "2006-11-20",
             "2009-11-16",
             "2019-10-28",
             "2023-11-13",
         )
-        self.assertHolidayName(f"{name} (observed)", dt)
-        self.assertNoNonObservedHoliday(dt)
+        self.assertHolidayName(f"{name} (observed)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_eid_al_fitr(self):
         name = "Eid-Ul-Fitr"
@@ -238,20 +229,20 @@ class TestTrinidadAndTobago(CommonCountryTests, TestCase):
             "2024-04-10",
             "2025-03-31",
         )
-        self.assertHolidayName(name, self.no_estimated_holidays, range(1963, 2050))
-        dt = (
+        self.assertIslamicNoEstimatedHolidayName(name, self.full_range)
+        obs_dts = (
             "2009-09-21",
             "2012-08-20",
             "2020-05-25",
         )
-        self.assertHolidayName(f"{name} (observed)", self.no_estimated_holidays, dt)
-        self.assertNoNonObservedHoliday(dt)
+        self.assertIslamicNoEstimatedHolidayName(f"{name} (observed)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_carnival_monday(self):
         name = "Carnival Monday"
-        self.assertHolidayName(
+        self.assertNoHolidayName(name)
+        self.assertOptionalHolidayName(
             name,
-            self.optional_holidays,
             "2020-02-24",
             "2021-02-15",
             "2022-02-28",
@@ -259,14 +250,13 @@ class TestTrinidadAndTobago(CommonCountryTests, TestCase):
             "2024-02-12",
             "2025-03-03",
         )
-        self.assertHolidayName(name, self.optional_holidays, range(1963, 2050))
-        self.assertNoHolidayName(name)
+        self.assertOptionalHolidayName(name, self.full_range)
 
     def test_carnival_tuesday(self):
         name = "Carnival Tuesday"
-        self.assertHolidayName(
+        self.assertNoHolidayName(name)
+        self.assertOptionalHolidayName(
             name,
-            self.optional_holidays,
             "2020-02-25",
             "2021-02-16",
             "2022-03-01",
@@ -274,8 +264,7 @@ class TestTrinidadAndTobago(CommonCountryTests, TestCase):
             "2024-02-13",
             "2025-03-04",
         )
-        self.assertHolidayName(name, self.optional_holidays, range(1963, 2050))
-        self.assertNoHolidayName(name)
+        self.assertOptionalHolidayName(name, self.full_range)
 
     def test_optional_2025(self):
         self.assertOptionalHolidaysInYear(
