@@ -39,9 +39,9 @@ class TestVI(CommonCountryTests, TestCase):
         self.assertLocalizedHolidays(
             ("2022-01-01", "New Year's Day"),
             ("2022-01-06", "Three Kings Day"),
-            ("2022-01-17", "Birthday of Martin Luther King, Jr.; Martin Luther King Jr. Day"),
+            ("2022-01-17", "Martin Luther King Jr. Day"),
             ("2022-02-14", "Valentine's Day"),
-            ("2022-02-21", "Presidents' Day; Washington's Birthday"),
+            ("2022-02-21", "Presidents' Day"),
             ("2022-03-17", "Saint Patrick's Day"),
             ("2022-03-31", "Transfer Day"),
             ("2022-04-14", "Holy Thursday"),
@@ -54,7 +54,7 @@ class TestVI(CommonCountryTests, TestCase):
             ("2022-07-03", "Emancipation Day"),
             ("2022-07-04", "Independence Day"),
             ("2022-09-05", "Labor Day"),
-            ("2022-10-10", "Columbus Day; Columbus Day and Puerto Rico Friendship Day"),
+            ("2022-10-10", "Columbus Day and Puerto Rico Friendship Day"),
             ("2022-10-31", "Halloween"),
             ("2022-11-01", "Liberty Day"),
             ("2022-11-11", "Veterans Day"),
@@ -68,9 +68,9 @@ class TestVI(CommonCountryTests, TestCase):
             "th",
             ("2022-01-01", "วันขึ้นปีใหม่"),
             ("2022-01-06", "วันสมโภชพระคริสต์แสดงองค์"),
-            ("2022-01-17", "วันมาร์ติน ลูเทอร์ คิง จูเนียร์; วันเกิดมาร์ติน ลูเทอร์ คิง จูเนียร์"),
+            ("2022-01-17", "วันมาร์ติน ลูเทอร์ คิง จูเนียร์"),
             ("2022-02-14", "วันวาเลนไทน์"),
-            ("2022-02-21", "วันประธานาธิบดี; วันเกิดวอชิงตัน"),
+            ("2022-02-21", "วันประธานาธิบดี"),
             ("2022-03-17", "วันนักบุญแพทริก"),
             ("2022-03-31", "วันส่งมอบดินแดน"),
             ("2022-04-14", "วันพฤหัสศักดิ์สิทธิ์"),
@@ -83,7 +83,7 @@ class TestVI(CommonCountryTests, TestCase):
             ("2022-07-03", "วันเลิกทาส"),
             ("2022-07-04", "วันประกาศอิสรภาพ"),
             ("2022-09-05", "วันแรงงาน"),
-            ("2022-10-10", "วันโคลัมบัส; วันโคลัมบัส และวันมิตรภาพกับเปอร์โตริโก"),
+            ("2022-10-10", "วันโคลัมบัส และวันมิตรภาพกับเปอร์โตริโก"),
             ("2022-10-31", "วันฮาโลวีน"),
             ("2022-11-01", "วันเลิกทาส"),
             ("2022-11-11", "วันทหารผ่านศึก"),
