@@ -489,6 +489,26 @@ class TestNationalStockExchangeOfIndia(CommonFinancialTests, TestCase):
             ("2023-12-25", "Christmas Day"),
         )
 
+    def test_l10n_gu(self):
+        self.assertLocalizedHolidays(
+            "gu",
+            ("2023-01-26", "પ્રજાસત્તાક દિવસ"),
+            ("2023-03-07", "હોળી"),
+            ("2023-03-30", "રામ નવમી"),
+            ("2023-04-04", "મહાવીર જયંતિ"),
+            ("2023-04-07", "ગુડ ફ્રાઈડે"),
+            ("2023-04-14", "ડૉ. બાબાસાહેબ આંબેડકર જયંતિ"),
+            ("2023-05-01", "મહારાષ્ટ્ર દિવસ"),
+            ("2023-06-28", "બકરી ઈદ"),
+            ("2023-08-15", "સ્વતંત્રતા દિવસ"),
+            ("2023-09-19", "ગણેશ ચતુર્થી"),
+            ("2023-10-02", "મહાત્મા ગાંધી જયંતિ"),
+            ("2023-10-24", "દશેરા"),
+            ("2023-11-14", "દિવાળી બલિપ્રતિપદા"),
+            ("2023-11-27", "ગુરુ નાનક જયંતિ"),
+            ("2023-12-25", "નાતાલ"),
+        )
+
     def test_l10n_hi(self):
         self.assertLocalizedHolidays(
             "hi",
